# Calculate length of each small stream reach in each scenario ----

#' Prep small stream data for use in capacity and spawning calculations
#' The fp_overlap field indicates whether or not a particular small stream reach
#' overlaps with fp habitat so that we do not double count these habitat units
#'
#' @param df_flowline Output of hab_clean_flowline()
#' @param run_scenario which scenario to run
#' @param run_era which era to run
#'
#' @export

hab_clean_ss <- function(df_flowline, run_scenario, run_era) {
  ss_clean <- df_flowline %>%
    filter.(
      Habitat == "SmStream",
      !pond_overlap,
      rear
    ) %>%
    mutate.(
      slope_class = reclass_slope(slope),
      lc = ifelse(lc %in% c("", " "),
        "Reference",
        as.character(lc)
      )
    ) %>%
    select.(
      noaaid,
      subbasin_num,
      length,
      slope,
      lc,
      spawn, rear,
      pop,
      BF_width,
      fpw,
      Area_km2,
      slope_class,
      Habitat
    ) %>%
    hab_create_run_df(run_scenario, ., run_era)

  return(ss_clean)
}
