#' Create historical side channels
#'
#' Create historical side channel data frame from flowline and hist channel data
#'  joined by reach
#'
#' @param df_flowline Output of hab_clean_flowline()
#' @export

hab_create_side_channels <- function(df_flowline) {
  hist_sc <- df_flowline %>%
    select.(
      length,
      spawn, rear,
      pop,
      subbasin_num,
      noaaid,
      Habitat,
      lg_slough
    ) %>%
    filter.(
      rear,
      Habitat == "LgStream") %>%
    left_join.(lr_length_raw, by = "subbasin_num") %>%
    mutate.(
      sc_mult = replace_na(sc_mult, 0),
      Length_sc = length * sc_mult*is.na(lg_slough), # no side channels on lg sloughs
      Area_ha = m2_to_ha(Length_sc * width_sc),
      Period = "Hist",
      in_fp = TRUE,
      Habitat = "Side_channel"
    ) %>%
    select.(
      noaaid,
      Area_ha,
      Length_sc,
      Period,
      in_fp,
      Habitat
    )

  curr_sc <- df_flowline %>%
    left_join.(SC_curr_raw, by = "noaa_subba") %>%
    filter.(Habitat == "LgStream")  %>%
    mutate.(
      tot_length = sum(length, na.rm = T),
      length_frac = length/tot_length,
      Length_sc = est_sc_km*length_frac*1000*is.na(lg_slough), # km to meters
      Area_ha = m2_to_ha(Length_sc*width_sc),
      Period = "Curr",
      bfw_conn = TRUE,
      in_fp = TRUE,
      Habitat = "Side_channel",
      .by = subbasin_num) %>%
    # filter to rearing streams AFTER apportioning SCs
    filter.(rear) %>%
    select.(
      noaaid,
      Area_ha,
      Length_sc,
      Period,
      bfw_conn,
      Habitat
    )

  bind_rows.(hist_sc, curr_sc)
}
