#Create entire floodplain data frame


#' Create the floodplain data frame
#'
#' Clean and create floodplain dataframe, including side channels
#'
#' @param df_side_channel output of hab_create_side_channels()
#' @param df_flowline Output of hab_clean_flowline()
#' @param run_scenario which scenario to run
#' @param run_era which era to run
#' @export

hab_clean_floodplain <- function(df_side_channel,
                                 df_flowline,
                                 run_scenario,
                                 run_era) {
  Floodplain_raw %>%
    # perimeter / width ~ Length of each side
    # this is specifically the length of NON-side channel features
    # but it's poorly named
    mutate.(Length_sc = 0) %>%
    bind_rows.(df_side_channel) %>%
    select.(
      Habitat,
      Area_ha,
      Period,
      Hab_cond,
      noaaid,
      bfw_conn,
      in_fp,
      Length_sc
    ) %>%
    hab_create_run_df(run_scenario, ., run_era) %>%
    join_flowline(df_flowline) %>%
    mutate.(
      slope_class = reclass_slope(slope),
      lc = "Forest" # all side channels considered forested. lc not used for
      # marshes and ponds
    ) %>%
    left_join.(pool_ratios, by = c("lc", "slope_class"))

}
