#' Prep the large river input file
#'
#' Join the attributed flowline to the large river edge habitats file,
#' bringing along only the necessary fields from the attributed flowline.
#' Filter the newly created large river dataframe to the spawning and rearing
#' distribution for a given species.
#'
#' @param run_pop Species of interest for this model run
#' @param df_flowline Attributed flowline
#' @export

hab_prep_lr <- function(run_pop, df_flowline) {
  EdgeHabs_raw %>%
    left_join.(
      df_flowline %>% # trim to avoid Habitat merge conflicts
        select.(noaaid, pop, rear, BF_width, subbasin_num),
      by = "noaaid") %>%
    filter.(
      rear, # trim to only include rearing habitat
      pop == run_pop) # redundant if run with default params
}
