#' Clean the backwater habitat areas
#'
#' @param df_flowline Output of hab_clean_flowline()
#' @param run_scenario which scenario to run
#' @param run_era which era to run
#'
#' @export

hab_clean_backwater <- function(df_flowline, df_sch, run_scenario, run_era){

  # calculate historic backwater area
  hist_bw <- df_sch %>%
    filter.(Period == "Hist") %>%
    mutate.(
      # bw scalar is ratio of mean backwater area to mean side channel length
      # so multiplying side channel length x the backwater scalar gives BW area
      Area_ha = m2_to_ha(bw_scalar * Length_sc),
    ) %>% filter.(Area_ha >0)

  Backwater_raw %>% # current backwaters
    join_flowline(df_flowline) %>%
    bind_rows.(hist_bw) %>% # add in historic
    mutate.(Habitat = "Backwater") %>%
    filter.(rear) %>%
    select.(
      subbasin_num,
      noaaid, pop,
      spawn, rear,
      Period,
      Habitat,
      Area_ha
    ) %>%
    hab_create_run_df(run_scenario, ., run_era) %>%
    left_join.(scenarios_df, by = c("noaaid", "scenario")) %>%
    mutate.(
      Area_ha = tidytable::if_else.(
        Period == 'Hist',
        apply_rest_action(0, Area_ha, rest_perc, fp_intensity_scalar),
        Area_ha),
      summer = Area_ha, # backwaters don't change seasonally in model
      winter = Area_ha) %>%
    tidytable::pivot_longer.(
      cols = summer:winter,
      names_to = 'life.stage',
      values_to = 'Area')
}



