# LgRiver ----

#' Clean the large river habitat areas
#' Calculate length of large river units
#'

#' @param run_pop which pop
#' @param df_lr hab_calc_lgr_area()
#' @param run_scenario which scenario to run
#' @param run_era which era to run
#'
#' @export

hab_calc_lr_length <- function(df_lr, run_scenario, run_era) {
  df_lr %>%
    hab_create_run_df(run_scenario, ., run_era) %>%
    left_join.(scenarios_df, by = c("noaaid", "scenario")) %>%
    left_join.(lr_length_raw, by = "subbasin_num") %>%
    mutate.(
      lr_mult = tidytable::replace_na.(lr_mult, 1),
      length_meander = apply_rest_action( # ratio: restored/current length
        1,
        lr_mult,
        rest_perc,
        lr_intensity_scalar
      ),
      # this apportions new river length between new (armored) and old
      # (non-armored) habitats. So an armored bank restored at 70% intensity
      # would have 70% of its new length as unarmored and 30% armored
      Length_m = tidytable::case_when.(
        Period == "Hist" ~
          Length_m * lr_intensity_scalar * length_meander,
        Period == "Curr" ~
          Length_m * (1 - lr_intensity_scalar) * length_meander,
        TRUE ~ Length_m * length_meander
      )
    ) %>%
    select.(
      subbasin_num,
      noaaid,
      Habitat,
      Length_m,
      BF_width,
      scenario,
      era,
      names(scenarios_df)
    )

}
