#' Calculate the area of large river habitat units
#'
#' @param df_lr_clean Output of hab_calc_lr_area()
#' @param df_width dataframe holding reach specific widths for each scenario
#' @param df_bw output of hab_clean_backwater()
#' @export

hab_calc_lr_area <- function(df_width, df_lr_clean, df_bw) {

  # calculate remaining width based on edge habitat
  area_lr_edge <- df_lr_clean %>%
    left_join.(df_width, by = "noaaid") %>%
    tidytable::expand_grid.(life.stage = c('summer', 'winter')) %>%
    mutate.(
      width_tot = tidytable::if_else.(life.stage == "summer", width_s, width_w),
      width = tidytable::case_when.(
        Habitat %in% c("Bar_boulder", "Bar_gravel", "Bar_sand") ~
          lr_width_scalar_bar * width_tot + lr_width_intercept_bar,
        Habitat == "Bank" ~
          lr_width_scalar_bank * width_tot + lr_width_intercept_bank,
        Habitat == "HM_Bank" ~
          lr_width_scalar_hm_bank * width_tot + lr_width_intercept_hm_bank,
        TRUE ~ NA_real_)
      )

  area_lr_edge %>%
    bind_rows.(area_lr_edge %>% # duplicate layer
      mutate.(
        Habitat = sprintf("%s_center", Habitat),
        width = (width_tot / 2) - width,
        # a small number of reaches where edge width is greater than wet width.
        # For now, we set the mid-channel width to 0 in these cases
        width = pmax(width, 0)
      )) %>%
    select.(-width_tot) %>%
    mutate.(Area = m2_to_ha(Length_m * width)) %>%
    bind_rows.(df_bw) %>%
    select.(
      noaaid,
      Habitat,
      subbasin_num,
      scenario,
      era,
      life.stage,
      Area,
      names(scenarios_df)
    )
}
