# Productivity calculations ----


#' Calculate productivity
#'
#' Productivity is weighted by capacity
#'
#' @param run_pop which pop to run
#' @param df_cap output of hab_calc_capacity()
#' @export

hab_calc_productivity <- function(run_pop, df_cap){

  # get survival-by-habitat data frame
  df_survival <- get(paste0('params_hab_',run_pop))$survival

  # join capacity and survival
  survival_base <- df_cap %>%
    left_join.(df_survival, by = c("Habitat", "life.stage")) %>%
    mutate.(
      surv_base_scenario = tidytable::if_else.(
        # for large river habitats, just use wood and temp mult
        Habitat %in% LgRiver_habs,
        surv_base * woodmult * tempmult,
        # for small river/floodplain habitats, use wood restoration and tempmult
        apply_rest_action(
          surv_base,
          wood_surv_base,
          rest_perc,
          wood_intensity_scalar
        ) * tempmult),
      # survival base maxes out at 1
        surv_base_scenario = pmin(surv_base_scenario, 1)
      )

  # survival is the weighted average of habitat survivals, weighted by capacity
  survival_base %>%
    filter.(!(is.na(capacity)) & !is.na(surv_base_scenario)) %>%
    tidytable::summarize.(
      survival = weighted.mean(surv_base_scenario, capacity, na.rm =T),
      capacity = sum(capacity, na.rm =T),
      .by = c(subbasin_num, life.stage, era, scenario)) %>%
    select.(
      subbasin_num,
      scenario,
      era,
      life.stage,
      capacity,
      survival)
}
