#16-movement



#' Calculate movement percents
#'
#' Calculate movement percents
#'
#' @param run_pop which pop to run
#' @param run_scenario which scenario to run
#'
#' @export


hab_calc_movement <- function(run_pop, run_scenario, df_fp){

  # filter scenario table to just this scenario
  subb_scalars <- scenarios_by_subb %>%
    filter.(scenario == run_scenario) %>%
    select.( # select only the fields we need
      subbasin_num, scenario,
      fp_intensity_scalar, beaver_intensity_scalar,
      wood_intensity_scalar, rest_perc)

  # make calculate coho movement percents on a subbasin scale
  movement_scen <- df_fp %>%
    tidytable::summarise.(
      fp_area_incr = any(area_increased), # did ANY of the FP areas increase?
      .by = c(subbasin_num, scenario)) %>%
    # join in scenario table to get scalars
    tidytable::right_join.(subb_scalars) %>%
    mutate.( # calculate movement change from wood or fp actions
      # replace any NAs with FALSE
      fp_area_incr = tidytable::replace_na.(fp_area_incr, FALSE),
      mvmt_from_wood = apply_rest_action(
        mvmt_base, mvmt_wood, wood_intensity_scalar, rest_perc),
      # for the fp action, only apply restoration if the fp areas have improved
      mvmt_from_fp = apply_rest_action(
        mvmt_base, mvmt_nat_potential,
        pmax(fp_intensity_scalar, beaver_intensity_scalar)*
          fp_area_incr, rest_perc),
      # then take the better of the two numbers for each subbasin
      movement = pmin(mvmt_from_wood, mvmt_from_fp)) %>%
    select.(subbasin_num, scenario, movement)

}

