#' Calculate spawning capacity in small streams
#'
#' Calculate spawning capacity in small streams. This function repeats much
#' of hab_clean_ss() in order to apply it to large streams between 20 and 30m
#'
#' @param run_pop which pop
#' @param df_ss_clean Output of hab_clean_ss()
#' @param df_width Dataframe with width values by reach
#'
#' @export


hab_calc_capacity_spawn_ss <- function(
    run_pop,
    df_flowline,
    df_width,
    beaver_model,
    run_scenario,
    run_era){

  redd_area <- get(paste0('params_hab_',run_pop))$redd_area
  fecundity <- get(paste0('params_hab_',run_pop))$fecundity

  ss_trim <- df_flowline %>%
    left_join.(df_width, by = c("noaaid")) %>%
    filter.(
      BF_width < 30,
      !pond_overlap,
      spawn,
    ) %>%
    hab_create_run_df(run_scenario, ., run_era)

  if(beaver_model == "BIP"){
    ss_beav_potent <- calc_BIP(ss_trim, slope, BF_width, fpw)
  } else if (beaver_model == "SP"){
    ss_beav_potent <- calc_pollock(ss_trim, slope, Area_km2)
  } else stop("Beaver model must be BIP or SP.")

  ss_beav_potent %>%
    left_join.(barriers_df, by = c("noaaid", "scenario")) %>%
    left_join.(scenarios_df, by = c("noaaid", "scenario")) %>%
    filter.(slope < .03) %>% # no spawning above a 3% grade
    mutate.(
      beaver_mult = tidytable::if_else(
        beav_hab, # only apply beaver action to potential habitat
        apply_rest_action(
          curr_beaver_mult,
          hist_beaver_mult,
          rest_perc,
          beaver_intensity_scalar),
        1),
      length = length * beaver_mult,
      psp_low_wood = tidytable::if_else.(slope < 0.01, psp_lwls, psp_lwhs),
      psp_high_wood = tidytable::if_else.(slope < 0.01, psp_hwls, psp_hwhs),
      psp = apply_rest_action(
        psp_low_wood,
        psp_high_wood,
        rest_perc,
        wood_intensity_scalar
      ),
      spawn_area = (length / (width_w * psp)) * width_w * (width_w * .5),
      eggs = spawn_area / redd_area * pass_tot_scenario * fecundity
    ) %>%
    select.(
      noaaid,
      subbasin_num,
      scenario,
      era,
      pop,
      Habitat,
      spawn_area,
      eggs,
      pass_tot_scenario,
      names(scenarios_df)
    )
}
