#' Calculate spawning capacity in side channels
#'
#' This function calculates spawning capacity in floodplain side channels
#'
#' @param run_pop which pop to run
#' @param df_fp_clean Output of hab_clean_floodplain()
#'
#' @export

hab_calc_capacity_spawn_fp <- function(run_pop, df_fp_clean){

  redd_area <- get(paste0('params_hab_',run_pop))$redd_area
  fecundity <- get(paste0('params_hab_',run_pop))$fecundity

  spawn_sc_raw <- df_fp_clean %>%
    filter.(
      Habitat == "Side_channel",
      # allow coho, winter steelhead to spawn in rearing SCs
      spawn | run_pop %in% c("coho", "winter_steelhead"))

    # summarize accessible length within each subbasin
  spawn_sc_raw %>%
    # current habs must be <5m from 1/2 BFW of strem.
    # historic habs must be in that distance or in floodplain
    mutate.(
      hist_length = (Period != "Curr")*(in_fp == 1|bfw_conn)*Length_sc,
      curr_length = (Period != "Hist")*(bfw_conn)*Length_sc) %>%
    tidytable::summarise.(
      tidytable::across.(c(hist_length, curr_length), sum, na.rm = T),
      .by = c(noaaid, Habitat, era, scenario, subbasin_num)) %>%
    left_join.(barriers_df, by = c("noaaid", "scenario")) %>%
    left_join.(scenarios_df, by = c("noaaid", "scenario")) %>%
    mutate.(
      curr_length = tidytable::replace_na.(curr_length, 0),
      hist_length = tidytable::replace_na.(hist_length, 0),
      length_sc = apply_rest_action(
        curr_length,
        hist_length,
        rest_perc,
        fp_intensity_scalar),
      spawn_area = length_sc /
        (width_sc * apply_rest_action(
          psp_lwls,
          psp_hwls,
          rest_perc,
          wood_intensity_scalar
        )) *
        width_sc *
        (width_sc * .5),
      eggs = spawn_area / redd_area * pass_tot_scenario * fecundity
    )

}
