#' Calculate spawning capacity in large rivers
#'
#' Read in the hand digitized riffle data
#' The riffle polygons are used to denote large river reaches that have one or
#' more riffles.
#'
#' @param df_flowline output of hab_clean_flowline()
#' @param df_width dataframe holding reach specific widths for each scenario
#' @param run_pop which pop
#' @param run_scenario which scenario to run
#' @param run_era which era to run
#'
#' @export

hab_calc_capacity_spawn_lr <- function(
  df_flowline,
  df_width,
  run_pop,
  run_scenario,
  run_era){

  # unused - widths do not vary by era or pop in this model
  #df_width <- filter(df_width, era == run_era, pop == run_pop)

  # add riffles by subbasin
  riff_area <- riff %>%
    tidytable::summarize.( # ha to m^2
      spawn_area = sum(Riffle_ha, na.rm = T)*10000, .by = noaaid)

  # Calculate total area for large river segments
  lgr_riffs <- df_flowline %>%
    filter.(
      BF_width >= 30,
      spawn,
      BF_width < 200 # exclude very wide rivers
    ) %>%

    # join in surveyed spawning areas
    left_join.(riff_area, by = "noaaid") %>%
    mutate.(
      spawn_area = tidytable::replace_na.(spawn_area, 0))
  redd_area <- get(paste0('params_hab_',run_pop))$redd_area
  fecundity <- get(paste0('params_hab_',run_pop))$fecundity

  hab_create_run_df(run_scenario, lgr_riffs, run_era) %>%
    left_join.(barriers_df, by = c("noaaid", "scenario")) %>%
    left_join.(scenarios_df, by = c("noaaid", "scenario")) %>%
    mutate.( # calc eggs based on restoration action
      eggs = spawn_area * pass_tot_scenario / redd_area * fecundity *
        apply_rest_action(
          1,
          wood_spawn_mult,
          rest_perc,
          wood_intensity_scalar)
    )


}
