#' Calculate egg capacity weights
#'
#' Prespawn and egg to fry productivities are weighted by egg
#'   capacity on a per reach basis
#'
#' @param df_splr_clean Output of hab_clean_capacity_spawn_lr()
#' @param df_spss Output of hab_calc_capacity_spawn_ss()
#' @param df_spfp Output of hab_calc_capacity_spawn_fp()
#'
#' @export

hab_calc_egg_cap <- function(df_splr_clean, df_spss, df_spfp){

  bind_rows.(df_spss, df_spfp, df_splr_clean) %>%
    filter.(!is.na(eggs)) %>% # remove empty spawning reaches
    tidytable::summarize.(
      eggs = sum(eggs, na.rm = T), # egg cap per noaaid
      .by = c(
        subbasin_num, noaaid,
        era, scenario,
        pass_tot_scenario,
        names(scenarios_df)))

}
