#' Calculate egg to fry productivity
#'
#' Egg to fry productivity is weighted by egg capacity on a reach basis.
#'
#' @param df_flowline output of hab_clean_flowline()
#' @param df_egg_cap Output of hab_calc_egg_cap()
#' @export


hab_calc_productivity_egg2fry <- function(df_flowline, df_egg_cap){


  df_flowline %>%
    select.(noaaid, ef_surv_current, ef_surv_hist) %>%
    tidytable::right_join.(df_egg_cap, by = c("noaaid")) %>%
    mutate.(
      ef_surv = apply_rest_action(
        ef_surv_current,
        ef_surv_hist,
        1,
        ef_intensity_scalar
      )) %>%
    tidytable::summarize.(
      survival = weighted.mean(ef_surv, eggs, na.rm =T),
      .by = c(subbasin_num, era, scenario)) %>%
    mutate.(life.stage = "egg.to.fry")

}
