#### Prespawn survival ----


#' Calculate prespawn productivity
#'
#' Prespawn productivity is weighted by egg capacity on a reach basis.
#' Spring chinook have a temperature function and coho have an impervious
#' suface function.
#'
#' @param run_pop which pop to run
#' @param run_scenario which scenario to run
#' @param run_era which era to run
#' @param df_flowline output of hab_clean_flowline()
#' @param df_egg_cap Output of hab_calc_egg_cap()
#' @param df_temperature dataframe with temps per reach
#'
#' @export

hab_calc_productivity_prespawn <- function(run_pop,
                                           run_scenario,
                                           run_era,
                                           df_flowline,
                                           df_egg_cap,
                                           df_temperature,
                                           pass_mort){


  prespawn_surv_raw <- get(paste0('params_hab_',run_pop))$prespawn_surv_raw

  hab_create_run_df(run_scenario, df_flowline, run_era) %>%
    tidytable::inner_join.( # only join in reaches with egg capacity
      df_egg_cap,
      by = c("noaaid", "subbasin_num", "scenario", "era")
    ) %>%
    left_join.(
      df_temperature, by = c("noaaid", "scenario", "era")) %>%
    mutate.(
      temp_mult = hab_bowerman_ps(temp_prespawn), # multiplier for chinook
      prespawn_surv = case_when(
        run_pop == "fall_chinook" ~ prespawn_surv_raw * temp_mult, # for chinook
        run_pop != "coho" ~ prespawn_surv_raw, # don't adjust steelhead
        Habitat == "LgStream" ~ prespawn_surv_raw, # and only in small streams
        era == "hist" ~ prespawn_surv_raw,
        era == "curr" ~ (1-psm) * prespawn_surv_raw # survival is 1-mortality
      ),
      passage_mortality = pass_mort, # logical from hab_run()
      pass_tot_scenario = ifelse(
        passage_mortality,
        pass_tot_scenario, # if passage mort is used, adjust by passage rating
        ceiling(pass_tot_scenario) # otherwise, use 0 (no passage) or 1 (any)
      ),
      survival = prespawn_surv * pass_tot_scenario
    ) %>%
    tidytable::summarize.(
      survival = weighted.mean(survival, eggs, na.rm = T),
      .by = c(subbasin_num, era, scenario)) %>%
    mutate.(life.stage = "prespawn")
}



