#### Delta Capacity ----


#' Calculate delta capacity
#'
#' Calculate delta capacity based on restoration scenario. Returns a numeric
#' value of annual delta capacity
#'
#' @param run_pop which pop to run
#' @param run_scenario which scenario to run
#'
#' @export

hab_calc_capacity_delta <- function(run_pop, run_scenario, run_era){

  if(run_pop != "fall_chinook"){
    delta_cap <- NA
  } else{
    delta_cap_hist <- params_hab_fall_chinook$delta_cap_hist
    delta_cap_curr <- params_hab_fall_chinook$delta_cap_curr

    # delta restoration happens at a basin scale
    scenario_details <- scenarios_df %>%
      filter.(scenario == run_scenario) %>%
      tidytable::distinct.( # pick out scenario details
        c(rest_perc, delta_intensity_scalar))

    delta_cap <- apply_rest_action(
      delta_cap_curr,
      delta_cap_hist,
      scenario_details$rest_perc,
      scenario_details$delta_intensity_scalar
    )
  }

  # make data frame
  subbasin_names %>%
    tidytable::transmute.(
      subbasin_num,
      scenario = run_scenario,
      era = run_era,
      life.stage = "delta",
      capacity = delta_cap

    )

}



