#' Organize data
#'
#' Gather all capacities and productivities and create output files
#'
#' @param run_pop which pop to run
#' @param df_prod output of hab_calc_productivity()
#' @param df_cap_spawn Output of hab_clean_capacity_spawn()
#' @param df_prod_prespawn Output of hab_calc_productivity_prespawn()
#' @param df_prod_e2f Output of hab_calc_productivity_egg2fry()
#' @param df_mvmt Output of hab_calc_movement()
#' @export


hab_organize <- function(run_pop,
                         df_prod,
                         df_cap_spawn,
                         df_prod_prespawn,
                         df_prod_e2f,
                         df_mvmt,
                         df_cap_delta){

  results_inputs <- bind_rows.( # combine all results
    df_prod,
    df_cap_spawn,
    df_prod_prespawn,
    df_prod_e2f,
    df_cap_delta) %>%
    # add movement
    left_join.(df_mvmt, by = c("subbasin_num", "scenario")) %>%
    filter.(!is.na(subbasin_num))

  results_inputs %>% # create season-lifestage pairs: e.g. winter capacity
    tidytable::pivot_longer.(
      c(capacity, survival, movement), names_to = "life.stage2") %>%
    tidytable::unite.(life.stage, life.stage2, col = life.stage, sep = ".") %>%
    tidytable::complete.( # fill in missing life stages in each subbasin with 0s
      life.stage, scenario,
      subbasin_num = subbasin_names$subbasin_num, # use all available subb #s
      fill = list(value = 0)) %>% # remove fill to use NAs instead
    tidytable::inner_join.(ls_names, by = "life.stage")%>% # rename lifestages
    tidytable::arrange.(stage_nums, subbasin_num) %>%
    tidytable::transmute.(
      pop = run_pop,
      scenario,
      subbasin_num,
      param = stage_nm,
      value
    )
}
