



#' Compare results on two different branches
#'
#' Default is to run Historical-Curr for all species on the current branch
#' and then again on the master branch
#'
#' @param branch1 first branch to compare, default is the branch you are in
#' @param branch2 second branch to compare, default is master
#' @param pops what pops to compare, default is pops_all
#' @param scenarios what scenarios to run, defaults is Historical
#' @param eras what eras to run, default is Curr
#'
#' @return If there are changes, the return is a list with 2 versions of results
#' @noRd
#'
#' @examples
#' compare_branches()
#' compare_branches(chk_lcm = TRUE)
#' compare_branches(scenarios = "All_75%")
compare_branches <- function(branch1 = system2('git', c('branch', '--show-current'), stdout = TRUE),
                             branch2 = 'master',
                             pops = pops_all,
                             scenarios = 'Historical',
                             eras = 'curr',
                             chk_lcm = FALSE) {


  chk_git <- system2('git', c('status', '--porcelain'), stdout = TRUE)
  if (length(chk_git) != 0) stop('compare_branches() requires a clean git status. Commit all changes')



  h <- map(c(branch1, branch2), function(b) {
    if (b != system2('git', c('branch', '--show-current'), stdout = TRUE)) {
      system2('git', args = c('checkout', b))
      devtools::load_all()
    }

    h <- crossing(pop = pops,
                  run_scenario = scenarios,
                  run_era = eras) %>%
      pmap_dfr(function(pop, run_scenario, run_era) {

        h <- hab_run(pop, run_scenario, run_era)

        if (chk_lcm) {
          l <- h %>%
            lcm_assign() %>% lcm_run()
          return(l)

        } else {
          return(h)
        }

        })
  })


  system2('git', args = c('checkout', branch1))
  devtools::load_all()

  if (length(unique.default(h)) == 1L) {
    message('No difference, not returning results')

  } else {
    message('Difference detected, returning results')

    return(h)
  }

}
