#' Reach-level passage values.
#'
#' A dataset containing the passage associated with each reach under each
#' scenario
#'
#' @format A tibble with 113,400 rows and 3 variables:
#' \describe{
#'   \item{noaaid}{reach ID}
#'   \item{pass_tot_scenario}{passage to reach under given scenario}
#'   \item{scenario}{which diagnostic or restoration scenario}
#' }
#' @source \describe{generated from the habitat scenario model}
"barriers_df"

#' Reach-level width values.
#'
#' A dataset containing the summer and winter widths associated with each reach
#'
#' @format A data frame with 5,400 rows and 3 variables:
#' \describe{
#'   \item{noaaid}{reach ID}
#'   \item{width_s}{summer wetted width, meters}
#'   \item{width_w}{winter wetted width, meters}
#' }
#' @source \describe{generated from the habitat scenario model}
"width_df"

#' Reach-level temperature values.
#'
#' A dataset containing the summer and winter widths associated with each reach
#'
#' @format A tibble with 226,800 rows and 6 variables:
#' \describe{
#'   \item{noaaid}{reach ID}
#'   \item{era}{era under which scenario is applied}
#'   \item{scenario}{which diagnostic or restoration scenario}
#'   \item{temp_Jn121}{mean maximum daily temperature between June 1-21}
#'   \item{temp_7DADM}{7-day average daily max August temperature}
#'   \item{temp_prespawn}{7-day average daily max August temperature}
#' }
#' @source \describe{generated from the habitat scenario model}
"temperature_df"

#' Reach-level scenario values.
#'
#' A dataset containing scalars tha vary by scenario and reach
#'
#' @format A tibble with 226,800 rows and 6 variables:
#' \describe{
#'   \item{scenario}{which diagnostic or restoration scenario}
#'   \item{noaaid}{reach ID}
#'   \item{Fine_sediment}{flag whether or not fine sediment values are altered}
#'   \item{LR}{flag whether or not large river banks are altered}
#'   \item{rest_perc}{percent of area influenced under scenario}
#'   \item{primary_cr_only}{deprecated}
#'   \item{managed_forest}{flag whether or not manage forest scenario is run}
#'   \item{beaver_intensity_scalar}{intensity of beaver restoration}
#'   \item{temp_intensity_scalar}{intensity of temperature restoration}
#'   \item{fp_intensity_scalar}{intensity of floodplain restoration}
#'   \item{wood_intensity_scalar}{intensity of wood restoration}
#'   \item{ef_intensity_scalar}{intensity of fine sediment restoration}
#'   \item{lr_intensity_scalar}{intensity of large river bank restoration}
#' }
#' @source \describe{generated from the habitat scenario model}
"scenarios_df"


# TO DOCUMENT LATER

# from 9-flowline_prep
# flowline_clean

# from lcm-params
# params_coho
# params_fall_chinook
# params_steelhead
