#' Chum LCM
#'
#' Define the life cycle model for a given species.
#' Not currently in use
#'
#' @param mat_in N matrix
#' @param mat_out blank N matrix
#' @param hab_params param list
#'
#' @export
lcm_chum <- function(mat_in, mat_out, hab_params) {

  list2env(hab_params, envir = environment())

  # Main chum function -----
  #Lifestages
  # 1)  Eggs
  # 2)  Pre Fry
  # 4)  Fry/Smolts
  # 5)  Ocean0 mat_in[1],
  # 6)  Ocean1 mat_in[2,]
  # 7)  Ocean2 mat_in[3,]
  # 8)  Total Run
  # 9)  Spawners


  NOR_total <- mat_in['spawners',]
  #NOR_total <- N["spawners",] # Run this line to be able to step through func

  eggs <- BH_func(S = NOR_total * sex_ratio, p = fecund, c = egg_cap) # B-H

  pre_fry <- eggs * egg_fry_surv

  fry <- BH_func(pre_fry, p = fry_colonization_surv, c = fry_colonization_cap * 1.1)

  fry_migrant <- fry * fry_migrant_surv


  # Apply bay survival (ds migration, delta, bay, nearshore productivity)
  fry_migrant_bay <- fry_migrant * bay_surv

  # Ocean survival
  mat_out['ocean0', ] <- fry_migrant_bay # smolts leaving bay, ocean0
  mat_out['ocean1', ] <- mat_in[1, ] * so1 # 2 year olds, ocean1
  mat_out['ocean2', ] <- mat_in[2, ] * (1 - b2) * so2 # 3 year olds, ocean2
  mat_out['ocean3', ] <- mat_in[3, ] * (1 - b3) * so3 # 4 year olds, ocean3
  mat_out['ocean4', ] <- mat_in[4, ] * (1 - b4) * so4 # 5 year olds, ocean4

  mat_out['total_run',] <- b2 * mat_in['ocean1', ] +
    b3 * mat_in['ocean2', ] +
    b4 * mat_in['ocean3', ] +
    b5 * mat_in['ocean4', ]

  mat_out['spawners',] <- mat_out['total_run', ] * S_up * (1 - hr) # Spawners

  mat_out['eggs', ] <- eggs
  mat_out['pre_fry', ] <- pre_fry
  mat_out['fry', ] <- fry
  mat_out['fry_migrant', ] <- fry_migrant
  mat_out['fry_migrant_bay', ] <- fry_migrant_bay


  return(mat_out)

}
