#' Replace NA with mean of group
#'
#' @param x a numeric vector
impute_mean <- function(x) replace(x, is.na(x), mean(x, na.rm = TRUE))

#' Break slope into classes "low", "medium" and "high"
#'
#' @param x a numeric vector
reclass_slope <- function(x){
  cut(x,
      breaks= c(-Inf, 0.02, 0.04, Inf),
      labels = c("low", "med", "high"),
      right = FALSE) %>% # slope of 0.2 is medium
    as.character.factor()
}

#' Convert square meters to hectares
#'
#' @param x area in m
m2_to_ha <- function(x){
  x / 10000
}

#' Join some flowline attributes onto other habitats
#'
#' @param x a habitat vector
#' @param df_flowline a species-specific flowline dataset
join_flowline <- function(x, df_flowline){
  df_flowline %>%
    select.(tidyr::any_of(c(
      "noaaid",
      "noaa_subba",
      "subbasin_num",
      "length",
      "lc",
      "slope",
      "pop",
      "spawn", "rear",
      "both_chk",
      "chino_mult"
  ))) %>%
    tidytable::right_join.(x, by = "noaaid")

}
