library(tidyverse)

# Run this script to recreate the .rda files in /data

# Detach the harp package so that this script does not use pre-loaded harp
# inputs.  If harp is not loaded, comment out the detach() line

if ('harp' %in% (.packages())) {
  detach(package:harp)
}

# Run all .R files in data-raw except this one

list.files('data-raw/scripts',
           recursive = TRUE,
           pattern = 'hab.+R$',
           full.names = TRUE) %>%
 lapply(source)

list.files('data-raw/scripts',
           recursive = TRUE,
           pattern = 'lcm.+R$',
           full.names = TRUE) %>%
  lapply(source)

list.files('data-raw/scripts',
           recursive = TRUE,
           pattern = 'stats',
           full.names = TRUE) %>%
  lapply(source)

#source('data-raw/stochastic_script/stochastic_flow.R')

# Write data to package
usethis::use_data(
  # ---- from 1-hab_read_datasets
  lr_length_raw,
  riff,
  EdgeHabs_raw,
  Backwater_raw,
  Floodplain_raw,
  SC_curr_raw,
  #fut_imperv,
  subbasin_names,
  scenario_desc,
  pool_ratios,
  # ----- from 2-inputs
  mainstem_subs,
  bw_scalar,
  wood_spawn_mult,
  hist_beaver_mult,
  hist_pond_area_per_m,
  curr_beaver_mult,
  curr_pond_area_per_m,
  winter_pool_scalar_warm,
  mvmt_base,
  mvmt_wood,
  mvmt_nat_potential,
  psp_lwls,
  psp_hwls,
  psp_lwhs,
  psp_hwhs,
  LgRiver_habs,
  SmStream_habs,
  Floodplain_habs,
  pops_all,
  eras_all,
  width_sc,
  # ----- from *fish_inputs
  params_hab_chum,
  params_hab_coho,
  params_hab_fall_chinook,
  #params_hab_spring_chinook,
  params_hab_winter_steelhead,
  params_hab_summer_steelhead,
  # ----- from 4-create_scenarios
  scenarios_all,
  scenarios_cust,
  scenarios_by_subb,
  # ----- from 6-width_prep
  #width_df,
  lr_width_scalar_bank,
  lr_width_scalar_bar,
  lr_width_scalar_hm_bank,
  lr_width_intercept_bank,
  lr_width_intercept_bar,
  lr_width_intercept_hm_bank,
  # ------ from ls_names
  ls_capacity,
  ls_names,
  # ------ from lcm-move_matrix
  mat_move_downstream,
  mat_move_nearest_ms_only,
  # ------ from environmental_stats
  logqmean,
  logqsd,
  logqskew,
  b0,
  b1,
  internal = TRUE, # make internal
  overwrite = TRUE
)

usethis::use_data( # store these large data sets for external access
  # from 5-barriers_prep
  barriers_df,
  # from 6-width_prep
  width_df,
  # from 7-temperature_prep
  temperature_df,
  # from 9-flowline_prep
  flowline_clean,
  scenarios_df,
  # from lcm-params
  params_coho,
  params_fall_chinook,
  params_steelhead,
  overwrite = TRUE,
  compress = 'xz'
)

# usethis::use_data(df_marss, overwrite = TRUE)
