# Habitat related inputs -------------------------------------------------------
# Categorize all habitat types used in the model
# Habitat types are categorized as large river, small stream, or floodplain

LgRiver_habs <-
  c(
    "Bank",
    "HM_Bank",
    "Bar_boulder",
    "Bar_gravel",
    "Bar_sand",
    "Backwater",
    'Bank_center',
    'HM_Bank_center',
    'Bar_boulder_center',
    'Bar_gravel_center',
    'Bar_sand_center'
  )

SmStream_habs <-
  c(
    "Pool",
    "Riffle",
    "Beaver.Pond"
  )

Floodplain_habs <-
  c(
    "FP_Channel", # unused #Q4T
    "Lake",
    "Marsh",
    "FP_Pond_lg",
    "FP_Pond_sm",
    "SC_pool",
    "SC_riffle",
    "Side_Channel"
  )


# Subbasin and reach related inputs --------------------------------------------
# This is a list of all mainstem subbasins

mainstem_subs <- subbasin_names %>%
  filter(is_ms) %>%
  pull(subbasin_num)

# Beaver related inputs --------------------------------------------------------
# Pond area per m is in units of ha/m
# Beaver mult is defined based on the following:
#   In historical beaver scenarios, beaver ponds take up 15% of all trib reaches
#   In current beaver scenarios, beaver ponds take up 1.375% of all trib reaches

hist_beaver_mult <- 0.85 # 1- (25m/pond * 6ponds/km)
hist_pond_area_per_m <- .0003 # (500m^2/pond * 6ponds/km)
curr_beaver_mult <- 0.992 # 1- (25m/pond * 0.32ponds/km)
curr_pond_area_per_m <- .000016 # (500m^2/pond * 32ponds/km)

# Spawning related inputs ------------------------------------------------------

# spawning gravel multiplier for hist wood scenarios
wood_spawn_mult <- 1.3

# Pool spacing varies by slope, wood condition

# low wood, low slope reaches
psp_lwls <- 12.5
# high wood, low slope reaches
psp_hwls <- 6.25
# low wood, high slope reaches
psp_lwhs <- 27.5
# high wood, high slope reaches
psp_hwhs <- 5


# Rearing related inputs -------------------------------------------------------

# Pool scalar used to augment winter pool area
winter_pool_scalar_warm <- .3

# Movement inputs --------------------------------------------------------------
mvmt_base <- 11
mvmt_wood <- 7
mvmt_nat_potential <- 3

# Other inputs -----------------------------------------------------------------

temp_conversion_scalar <- 0.35832 # for Stillaguamish. temp_June ~ temp_7DADM

bw_scalar <- .109 # for Stillaguamish

# Define all pops run through model
pops_all <- c('coho','fall_chinook', 'winter_steelhead', 'summer_steelhead')

# Define all eras run through model
#eras_all <- c('hist', 'curr', 'mid', 'late')
eras_all <- c('hist', 'curr')

# Side channel width was set to 2m in Chehalis model.
# This value is average of field survey wetted widths.
width_sc <- 6.82
