# Spawning ---------------------------------------------------------------------
fecundity = 5400
redd_area = 14.1
adult_per_redd = 1.9

# Rearing ----------------------------------------------------------------------

# Capacity
density <- tribble(
  ~Habitat,             ~summer, ~winter, ~summer.2,
  "Bank",               12700,   300,     4700,
  "HM_Bank",            1400,    800,     200,
  "Bar_boulder",        0,       400,     1100,
  "Bar_gravel",         6400,    400,     1100,
  "Bar_sand",           3200,    400,     1100,
  "Backwater",          19100,   300,     2000,
  "Pool",               500,     30,      2000,
  "Riffle",             200,     0,       500,
  "Beaver.Pond",        1700,    1020,    1700,
  "Lake",               0,       0,       0,
  "Marsh",              0,       0,       0,
  "FP_Pond_lg",         1700,    1020,    1700,
  "FP_Pond_sm",         1700,    1020,    1700,
  "SC_pool",            500,     30,      2000,
  "SC_riffle",          200,     0,       500,
  "Bank_center",        38,      38,      38,
  "HM_Bank_center",     38,      38,      38,
  "Bar_boulder_center", 38,      38,      38,
  "Bar_gravel_center",  38,      38,      38,
  "Bar_sand_center",    38,      38,      38) %>%
  mutate(summer.t = summer) %>% # make a second copy of 1st summer
  pivot_longer(cols = summer:summer.t,
               names_to = 'life.stage',
               values_to = 'density')

# Productivity
surv_summer1 <- tribble(
  ~Habitat, ~surv_base, ~wood_surv_base,
  "Bank", .26, .26,
  "HM_Bank", .26, .26,
  "Bar_boulder", .26, .26,
  "Bar_gravel", .26, .26,
  "Bar_sand", .26, .26,
  "Backwater", .26, .26,
  "Pool", .26, .43,
  "Riffle", .26, .43,
  "Beaver.Pond", .5, .5,
  "FP_Channel", .5, .5,
  "Lake", .5, .5,
  "Marsh", .5, .5,
  "FP_Pond_lg", .5, .5,
  "FP_Pond_sm", .5, .5,
  "SC_pool", .26, .43,
  "SC_riffle", .26, .43,
  "Slough_lg", .5, .5,
  "Slough_sm", .5, .5,
  "Bank_center", .26, .26,
  "HM_Bank_center", .26, .26,
  "Bar_boulder_center", .26, .26,
  "Bar_gravel_center", .26, .26,
  "Bar_sand_center", .26, .26,
) %>%
  crossing(life.stage = c('summer', 'summer.t'))

surv_summer2 <- tribble( # copied from coho survival, centers from steelhead
  ~Habitat, ~surv_base, ~wood_surv_base,
  "Bank", .84, .84,
  "HM_Bank", .84, .84,
  "Bar_boulder", .84, .84,
  "Bar_gravel", .84, .84,
  "Bar_sand", .84, .84,
  "Backwater", .84, .84,
  "Pool", .84, .9,
  "Riffle", .84, .9,
  "Beaver.Pond", .84, .84,
  "FP_Channel", .84, .84,
  "Lake", .84, .84,
  "Marsh", .84, .84,
  "FP_Pond_lg", .84, .84,
  "FP_Pond_sm", .84, .84,
  "SC_pool", .84, .9,
  "SC_riffle", .84, .9,
  "Slough_lg", .84, .84,
  "Slough_sm", .84, .84,
  "Bank_center", .85, .85,
  "HM_Bank_center", .85, .85,
  "Bar_boulder_center", .85, .85,
  "Bar_gravel_center", .85, .85,
  "Bar_sand_center", .85, .85) %>%
  mutate(life.stage = 'summer.2')

surv_winter <- tribble( # copied from coho survival, centers from steelhead
  ~Habitat, ~surv_base, ~wood_surv_base,
  "Bank", .35, .35,
  "HM_Bank", .35, .35,
  "Bar_boulder", .35, .35,
  "Bar_gravel", .35, .35,
  "Bar_sand", .35, .35,
  "Backwater", .35, .35,
  "Pool", .35, .58,
  "Riffle", .35, .58,
  "Beaver.Pond", .78, .78,
  "FP_Channel", .4, .4,
  "Lake", .4, .4,
  "Marsh", .78, .78,
  "FP_Pond_lg", .78, .78,
  "FP_Pond_sm", .78, .78,
  "SC_pool", .35, .58,
  "SC_riffle", .35, .58,
  "Slough_lg", .4, .4,
  "Slough_sm", .4, .4,
  "Bank_center", .35, .35,
  "HM_Bank_center", .35, .35,
  "Bar_boulder_center", .35, .35,
  "Bar_gravel_center", .35, .35,
  "Bar_sand_center", .35, .35) %>%
  mutate(life.stage = 'winter')

survival <- bind_rows(surv_summer1, surv_summer2, surv_winter)

# Wood multipliers for large river ---------------------------------------------
# Summer
lr_wd_s_bank <- 1.16
lr_wd_s_bar <- 1.03

# Winter
lr_wd_w_bank <- 1.21 # copied from coho
lr_wd_w_bar <- 1.09

# Prespawn survival ------------------------------------------------------------
prespawn_surv_raw <- 1

# Delta habitat ----------------------------------------------------------------
delta_cap_curr <-  75559  # from GIS analysis
delta_cap_hist <- 370267


params_hab_fall_chinook <- dplyr::lst(fecundity,
                                      redd_area,
                                      adult_per_redd,
                                      density,
                                      survival,
                                      lr_wd_s_bank,
                                      lr_wd_s_bar,
                                      lr_wd_w_bank,
                                      lr_wd_w_bar,
                                      prespawn_surv_raw,
                                      delta_cap_curr,
                                      delta_cap_hist)

