# Spawning ---------------------------------------------------------------------
fecundity = 5400
redd_area = 5.4
adult_per_redd = 1.3

# Rearing ----------------------------------------------------------------------

# Capacity
density <- tribble(
  ~Habitat,             ~summer, ~winter, ~summer.2, ~winter.2,
  "Bank",               12700,   3100,    3900,      960,
  "HM_Bank",            6400,    3100,    2000,      960,
  "Bar_boulder",        15900,   3100,    4900,      960,
  "Bar_gravel",         15900,   3100,    4900,      960,
  "Bar_sand",           0,       0,       0,         0,
  "Backwater",          12700,   0,       3900,      0,
  "Pool",               7000,    1600,    1800,      900,
  "Riffle",             5300,    1100,    700,       400,
  "Beaver.Pond",        0,       300,     700,       100,
  "FP_Channel",         0,       0,       0,         0,
  "Lake",               0,       0,       0,         0,
  "Marsh",              0,       0,       0,         0,
  "FP_Pond_lg",         0,       300,     700,       100,
  "FP_Pond_sm",         0,       300,     700,       100,
  "SC_pool",            7000,    1600,    1800,      900,
  "SC_riffle",          5300,    1100,    700,       400,
  "Slough_lg",          0,       0,       0,         0,
  "Slough_sm",          0,       0,       0,         0,
  "Bank_center",        640,     160,     1100,      270,
  "HM_Bank_center",     640,     160,     1100,      270,
  "Bar_boulder_center", 640,     160,     1100,      270,
  "Bar_gravel_center",  640,     160,     1100,      270,
  "Bar_sand_center",    640,     160,     1100,      270) %>%
  pivot_longer(
    cols = summer:winter.2,
    names_to = 'life.stage',
    values_to = 'density')

# Productivity
surv_base <- tribble(
  ~Habitat,             ~summer, ~winter, ~summer.2, ~winter.2,
  "Bank",               .6,      .49,     .72,       .58,
  "HM_Bank",            .6,      .49,     .72,       .58,
  "Bar_boulder",        .6,      .49,     .72,       .58,
  "Bar_gravel",         .6,      .49,     .72,       .58,
  "Bar_sand",           .6,      .49,     .72,       .58,
  "Backwater",          .6,      .49,     .72,       .58,
  "Pool",               .6,      .49,     .72,       .58,
  "Riffle",             .6,      .49,     .72,       .58,
  "Beaver.Pond",        .74,     .52,     .74,       .58,
  "FP_Channel",         .74,     .52,     .74,       .58,
  "Lake",               .74,     .52,     .74,       .58,
  "Marsh",              .74,     .52,     .74,       .58,
  "FP_Pond_lg",         .74,     .52,     .74,       .58,
  "FP_Pond_sm",         .74,     .52,     .74,       .58,
  "SC_pool",            .6,      .49,     .72,       .58,
  "SC_riffle",          .6,      .49,     .72,       .58,
  "Slough_lg",          .74,     .52,     .74,       .58,
  "Slough_sm",          .74,     .52,     .74,       .58,
  "Bank_center",        .6,      .49,     .72,       .58,
  "HM_Bank_center",     .6,      .49,     .72,       .58,
  "Bar_boulder_center", .6,      .49,     .72,       .58,
  "Bar_gravel_center",  .6,      .49,     .72,       .58,
  "Bar_sand_center",    .6,      .49,     .72,       .58) %>%
  pivot_longer(
    cols = summer:winter.2,
    names_to = 'life.stage',
    values_to = 'surv_base')

surv_base_wood <- tribble(
  ~Habitat,             ~summer, ~winter, ~summer.2, ~winter.2,
  "Bank",               .6,      .49,     .72,       .58,
  "HM_Bank",            .6,      .49,     .72,       .58,
  "Bar_boulder",        .6,      .49,     .72,       .58,
  "Bar_gravel",         .6,      .49,     .72,       .58,
  "Bar_sand",           .6,      .49,     .72,       .58,
  "Backwater",          .6,      .49,     .72,       .58,
  "Pool",               .63,     .54,     .76,       .64,
  "Riffle",             .63,     .54,     .76,       .64,
  "Beaver.Pond",        .74,     .52,     .74,       .58,
  "FP_Channel",         .74,     .52,     .74,       .58,
  "Lake",               .74,     .52,     .74,       .58,
  "Marsh",              .74,     .52,     .74,       .58,
  "FP_Pond_lg",         .74,     .52,     .74,       .58,
  "FP_Pond_sm",         .74,     .52,     .74,       .58,
  "SC_pool",            .63,     .54,     .76,       .58,
  "SC_riffle",          .63,     .54,     .76,       .58,
  "Slough_lg",          .74,     .52,     .74,       .64,
  "Slough_sm",          .74,     .52,     .74,       .64,
  "Bank_center",        .6,      .49,     .72,       .58,
  "HM_Bank_center",     .6,      .49,     .72,       .58,
  "Bar_boulder_center", .6,      .49,     .72,       .58,
  "Bar_gravel_center",  .6,      .49,     .72,       .58,
  "Bar_sand_center",    .6,      .49,     .72,       .58) %>%
  pivot_longer(
    cols = summer:winter.2,
    names_to = 'life.stage',
    values_to = 'wood_surv_base')

survival <- full_join(surv_base, surv_base_wood,
                      by = c("Habitat", "life.stage"))

# Wood multipliers for large river ---------------------------------------------
# Summer
lr_wd_s_bank <- 1.052
lr_wd_s_bar <- 1.011

# Winter
lr_wd_w_bank <- 1.069
lr_wd_w_bar <- 1.108

# Prespawn survival ------------------------------------------------------------
prespawn_surv_raw <- .95



params_hab_steelhead <- dplyr::lst(fecundity,
                                   redd_area,
                                   adult_per_redd,
                                   density,
                                   survival,
                                   lr_wd_s_bank,
                                   lr_wd_s_bar,
                                   lr_wd_w_bank,
                                   lr_wd_w_bar,
                                   prespawn_surv_raw)

params_hab_winter_steelhead <- params_hab_steelhead
params_hab_summer_steelhead <- params_hab_steelhead

