# Prep scenarios and restoration actions ---------------------------------------

# Subset flowline to spatial identifiers (noaaid), subbasins,
# and confinement features only
flowline_id <- flowline_raw %>%
  transmute(
    noaaid,
    confined = fpw/BF_width < 4,
    noaa_subba)

diagnostic_table <- # table of diagnostic scenarios
  tribble(
    ~scenario,       ~barrier, ~beaver, ~temp,  ~fp, ~wood,  ~ef,  ~lr, ~delta,
    "Current",              0,       0,     0,    0,     0,    0,    0,      0,
    "Barriers",          1.00,       0,     0,    0,     0,    0,    0,      0,
    "Beaver",               0,    1.00,     0,    0,     0,    0,    0,      0,
    "Shade",                0,       0,  1.00,    0,     0,    0,    0,      0,
    "Floodplain",           0,       0,     0, 1.00,     0,    0,    0,      0,
    "Wood",                 0,       0,     0,    0,  1.00,    0,    0,      0,
    "Fine_sediment",        0,       0,     0,    0,     0, 1.00,    0,      0,
    "LR",                   0,       0,     0,    0,     0,    0, 1.00,      0,
    "Delta",                0,       0,     0,    0,     0,    0,    0,   1.00,
    "FP_wood_comb",         0,       0,     0, 1.00,  1.00,    0,    0,      0,
    "Historical",        1.00,    1.00,  1.00, 1.00,  1.00, 1.00, 1.00,   1.00)

combo_table <- # table of "combination" scenarios, updated to Stillaguamish
  tribble(
    ~scenario,  ~barrier, ~beaver,  ~temp,   ~fp, ~wood,   ~ef,  ~lr, ~delta,
    'Top4_25%',        0,    0.25,   0.25,  0.25,  0.25,     0,     0,      0,
    'Top4_50%',        0,    0.50,   0.50,  0.50,  0.50,     0,     0,      0,
    'Top4_75%',        0,    0.75,   0.75,  0.75,  0.75,     0,     0,      0,

    'Top5_25%',        0,    0.25,   0.25,  0.25,  0.25,     0,  0.25,      0,
    'Top5_50%',        0,    0.50,   0.50,  0.50,  0.50,     0,  0.50,      0,
    'Top5_75%',        0,    0.75,   0.75,  0.75,  0.75,     0,  0.75,      0,

    'All_25%',         0,    0.25,   0.25,  0.25,  0.25,  0.25,  0.25,   0.25,
    'All_50%',         0,    0.50,   0.50,  0.50,  0.50,  0.50,  0.50,   0.50,
    'All_75%',         0,    0.75,   0.75,  0.75,  0.75,  0.75,  0.75,   0.75,
    'All_100%',     1.00,    1.00,   1.00,  1.00,  1.00,  1.00,  1.00,   1.00)

# combine diagnostic and combo scenarios
# NOTE: partial barrier removal is currently not supported
diag_combo_scenarios <- bind_rows(diagnostic_table, combo_table) %>%
  transmute(
    scenario,
    rest_perc = 1, # rest_perc is always 1
    barrier_intensity_scalar = barrier,
    beaver_intensity_scalar = beaver,
    temp_intensity_scalar = temp,
    fp_intensity_scalar = fp,
    wood_intensity_scalar = wood,
    ef_intensity_scalar = ef,
    lr_intensity_scalar = lr,
    delta_intensity_scalar = delta) %>%
  expand_grid(flowline_id, .) # combine with flowline

# combine custom scenarios with the flowline by subbasin
custom_scenarios <- custom_scen %>%
  mutate(rest_perc = 1) %>%
  inner_join(flowline_id, by = "noaa_subba")

scenarios_cust <- unique(custom_scen$scenario) # vector of all custom scenarios

if(nrow(custom_scenarios) %% nrow(flowline_id) !=0){
  stop("Error in custom scenarios. Check that all subbasins are accounted for")}

# combine custom and built-in scenarios
scenarios_by_noaaid <- bind_rows(diag_combo_scenarios, custom_scenarios) %>%
  arrange(scenario, noaaid)

# make table of scenarios and actions by subbasin
scenarios_by_subb <- scenarios_by_noaaid %>%
  group_by(scenario, noaa_subba) %>%
  summarize(across(c(
    barrier_intensity_scalar,
    beaver_intensity_scalar,
    temp_intensity_scalar,
    fp_intensity_scalar,
    wood_intensity_scalar,
    ef_intensity_scalar,
    lr_intensity_scalar,
    delta_intensity_scalar,
    rest_perc),
    first)) %>%
  left_join(select(subbasin_names, noaa_subba, subbasin_num), by = "noaa_subba")

scenarios_df <- scenarios_by_noaaid %>%
  select(-noaa_subba)

# vector of all allowed scenarios
scenarios_all <- unique(scenarios_df$scenario)
