# First run data-raw/hab_read_datasets.R



# function to calculate e2f survival based on species, percent fines
calc_e2f <- function(pop, perc_fines){
  case_when(
    grepl("steelhead", pop) ~
      case_when(
        perc_fines <= 20 ~ 0.52,
        perc_fines > 20 & perc_fines <= 40 ~ 0.52-0.025*(perc_fines-20),
        perc_fines > 40 ~ 0.02),
    pop %in% c("fall_chinook", "coho") ~
        case_when(
          perc_fines <= 54 ~ -0.014*perc_fines+0.75,
          perc_fines > 54 ~ 0))
  }


# calculate additional fields and pivot longer by species
flowline_clean <- flowline_raw %>%
  rename(
    fall_chinook = Chinook,
    coho = Coho,
    winter_steelhead = WSteelhead,
    summer_steelhead = SSteelhead) %>%
  pivot_longer(
    cols = c("coho", "fall_chinook", "winter_steelhead", "summer_steelhead"),
    names_to = "pop", values_to = "dist") %>%
  mutate(
    spawn = dist == "Spawning",
    rear = dist %in% c("Spawning", "Rearing"), # fish rear in spawning streams
    perc_fines_curr = finesed_c,
    perc_fines_hist = finesed_hc,
    ef_surv_current = calc_e2f(pop, perc_fines_curr),
    ef_surv_hist = calc_e2f(pop, perc_fines_hist),
    psm = pmax(psm_c, 0), # NA values (-1000) are replaced with 0 mortality
    pond_overlap = !is.na(pond_overl)
  ) %>%
  select(any_of(c(
    "noaaid",
    "Habitat",
    "slope",
    "temp",
    "BF_width",
    "length",
    "lc",
    "fpw",
    "noaa_subba",
    "Area_km2",
    "ef_surv_current",
    "ef_surv_hist",
    "fpw",
    "subbasin_num",
    "pond_overlap",
    "lg_slough",
    "psm",
    "pop",
    "spawn",
    "rear"
  )))

scenarios_df <- scenarios_df %>%
  select(
    noaaid,
    scenario,
    confined,
    rest_perc,
    beaver_intensity_scalar,
    temp_intensity_scalar,
    fp_intensity_scalar,
    wood_intensity_scalar,
    ef_intensity_scalar,
    lr_intensity_scalar,
    delta_intensity_scalar
  )

