# Creates movement matrices for the LCM
subb_names <- pull(subbasin_names, noaa_subba)

# we use position indices rather than subbasin numbers to build movement
# matrices - this allows greater flexibility to add or remove subbasins in the
# input tables/spatial data.
# create lookup table of subbasin numbers vs. position index
# this is a named vector to go with `recode`
subbasin_ids <- subbasin_names %>%
  mutate(id = row_number()) %>%
  transmute(subb_num = subbasin_num, id) %>%
  deframe()

# turns a vector of subbasin numbers into indices
subb_num_to_index <- function(subb_nums){
  dplyr::recode(subb_nums, !!!subbasin_ids)
}

# Create movement matrices for spring and fall  ----

# create matrix of subbasins and the mainstream subb immediately downstream
# these objects contain indexes used to fill the movement matrixes
near_mat <- subbasin_names %>%
  transmute(
    id = subb_num_to_index(subbasin_num),
    id_near = subb_num_to_index(nearest_ms)) %>%
  as.matrix()

# again but with all subbasins downstream of the originating one
downstr_mat <- subbasin_names %>%
  separate_rows(downstr_ms) %>%
  transmute(
    id = subb_num_to_index(subbasin_num),
    id_near = subb_num_to_index(downstr_ms)) %>%
  as.matrix

# blank matrix
mat_move <- matrix(
  0,
  nrow = length(subb_names),
  ncol = length(subb_names),
  dimnames = list(
    natal_basin = subb_names,
    rearing_basin = subb_names
  ))

# make one that moves fish only to the nearest mainstem subbasin
mat_move_nearest_ms_only <- mat_move
mat_move_nearest_ms_only[near_mat] <- 1

# move fish to all downstream subbasins
mat_move[downstr_mat] <- 1

# in this version, movement split evenly between natal basin and downstream
mat_move_downstream <- mat_move
mat_move_downstream <- prop.table(mat_move_downstream, 1)
mat_move_downstream[is.nan(mat_move_downstream)] <- 0

# # in this version, movement split evenly between natal basin and downstream
# mat_move_natal_to_bay <- mat_move
# diag(mat_move_natal_to_bay) <- 1
# mat_move_natal_to_bay <- prop.table(mat_move_natal_to_bay, 1)
#
#
# # in this version, movement is split only between downstream mainstem basins
# mat_move_ms_to_bay <- mat_move
# mat_move_ms_to_bay <- prop.table(mat_move_ms_to_bay, 1)
# mat_move_ms_to_bay[is.nan(mat_move_ms_to_bay)] <- 0

