# Parameters for Chehalis Fall Chinook salmon


#Initial condtions for the model -----------------------------------------------
pop.init <- 20000


# Fecundity --------------------------------------------------------------------
fecund <- 5400

# Fry migration mortality ------------------------------------------------------
fry_migr_prod <- 0.063390686 # calibrated

# Density-dependent delta parameters (for fry outmigrants)----------------------
delta_prod <- 0.35

# Post-s3 ocean survival -------------------------------------------------------

# Age structured ocean survivals
# stochastic survival between min and max
# min and max for each year in the ocean
so.1 <- .6#c(0.6, 0.6)#c(0.5,0.7)
so.2 <- .7#c(0.7, 0.7)#c(0.6,0.8)
so.3 <- .8#c(0.8, 0.8)#c(0.7,0.9)
so.4 <- .9#c(0.9, 0.9)#c(0.8,1)
so.5 <- .9#c(0.9, 0.9)#c(0.8,1)


# Propensity to return from the ocean as age bx --------------------------------
# Modified from Corey's paper. Table 2

# solved system of equations for Stillaguamish age structure
b0_2 <- 36/721
b0_3 <- 324/959
b0_4 <- 117/127
b5 <- 1
# snohomish age structure
b1_2 <- 28/363
b1_3 <- 32/67
# Pre harvest SAR

# Ocean survival coefficients - relationships between each saltwater age pop

# subyearling constants are not used
# o0_1 <- so.1
# o0_2 <- so.2*(1-b0_2)
# o0_3 <- so.3*(1-b0_3)
# o0_4 <- so.4*(1-b0_4)

# SW constants for yearling outmigrants
o1_1 <- so.1
o1_2 <- so.2*(1-b1_2)
o1_3 <- so.3*(1-b1_3)

target_SAR_1 <- 0.026

# ps_parr_surv <- target_parrSAR_0/
#   (o0_1*b0_2+ # year 2 returns
#      o0_1*o0_2*b0_3+ # year 3 returns
#      o0_1*o0_2*o0_3*b0_4+ # year 4 returns
#      o0_1*o0_2*o0_3*o0_4) # year 5 returns

ps_parr_surv <- 0.024795591 # calibrated

# The total number of returners is the number of smolts * the PS survival * the
# sum of each of the returner constants. So the SAR is just the PS survival *
# the returner sums. PS survival can then be calculated from a given SAR. This
# is only done with the yearling migrants since the math does not work with the
# two separate subyearling inputs.
ps_yr_surv <- target_SAR_1/
  (o1_1*b1_2+ # year 2 returns
     o1_1*o1_2*b1_3+ # year 3 returns
     o1_1*o1_2*o1_3) # year 5 returns

# Harvest rate -----------------------------------------------------------------

Hr <- 0#.36 # latest estimate (from Eric Walther, May 2017; average)

# Subyearling ratio ------------------------------------------------------------

# percent of subyearlings that will stay to become yearlings
subyr_ratio <- 0.998739232 # calibrated value


params_fall_chinook <- c(pop_init = pop.init,
                         fecund = fecund,
                         sex_ratio = 0.5,
                         fry_migr_prod = fry_migr_prod,
                         delta_prod = delta_prod,
                         ps_parr_surv = ps_parr_surv,
                         ps_yr_surv = ps_yr_surv,
                         so1 = so.1,
                         so2 = so.2,
                         so3 = so.3,
                         so4 = so.4,
                         so5 = so.5,
                         b0_2 = b0_2,
                         b0_3 = b0_3,
                         b0_4 = b0_4,
                         b1_2 = b1_2,
                         b1_3 = b1_3,
                         subyr_ratio = subyr_ratio,
                         tot_bs = 140,
                         hr = Hr)
