# Parameters for Chehalis steelhead


#Initial conditions for the model ----------------------------------------------
pop.init <- 8700


# Fecundity --------------------------------------------------------------------
fecund.first <- 5400 # First time spawner fecundity
fecund.respawn <- 8000 # Respawner fecundity


# fall redistribution ----------------------------------------------------------
# Percent of fish that move from natal basin down to mainstem in the fall
# See trello card:
#https://trello.com/c/DjGWaYoX/204-add-fall-movement-for-age-0-steelhead-end-of-first-summer

percent.fall.migrants <- subbasin_names %>%
  mutate(prcnt_movers = case_when(
    subb_area > 450             ~ 0.0,
    between(subb_area, 50, 450) ~ 0.02,
    subb_area < 50              ~ 0.1
  )) %>%
  pull(prcnt_movers)


# spring redistribution --------------------------------------------------------
# Percent of fish that move from natal basin down to mainstem in the spring
# See memo from Tim (NOAA LCM steelhead juvenile movement Chehalis #18)

percent.spring.migrants <- subbasin_names %>%
  mutate(prcnt_movers = case_when(
    subb_area > 450              ~ 0.00,
    between(subb_area, 100, 450) ~ 0.10,
    subb_area < 100              ~ 0.18
  )) %>%
  pull(prcnt_movers)


# need to tune based on present conditions
# calibrated to Snohomish age structure under Stillaguamish habitat conditions
# bay survival and smolting rates must be calibrated TOGETHER after saltwater
# maturation rates are calculated. Use the optim() function to minimize
# arbitrary functions

prop.age1.smolts.w <- 0.02746788
prop.age2.smolts.w <- 0.718166836
prop.age1.smolts.s <- 0.004780114
prop.age2.smolts.s <- 0.629139976

# Delta survivals and capacities -----------------------------------------------
# Included in Bay survivals



# Bay survival -----------------------------------------------------------------
# Capacity is assumed unlimited (transient)
# stochastic survival between min and max

bay.surv.w <- 0.021544931
bay.surv.s <- 0.023842524





# Post-s3 ocean survival -------------------------------------------------------
# stochastic survival between min and max

So <- 0.80# ocean survival after first year
so.min <- 0.80
so <- 0.80


# Propensity to return from the ocean as age bx --------------------------------


# Return from ocean to spawn probabilities, first time spawners
# these are calibrated to Snohomish using system of equations
b1_1w <- 340/963
b1_2w <- 1

b2_1w <- 63008/140493
b2_2w <- 15072/15497
#b2_3 <- 1

b3_1w <- 85/262
#b3_2 <- 1

b4_1w <- 1

b1_1s <- 0
b1_2s <- 4/9
#b1_3 <- 1

b2_1s <- 4/159
b2_2s <- 88/93
#b2_3 <- 1

b3_1s <- 4/109
#b3_2 <- 1



# Respawn rate --

# Clemens (2015) suggests that coastal populations generally have a higher
# iteroparity rate than non-coastal, this
# is in the range for coastal populations

# For a given year, what percent of the spawners are repeat spawners
kelt.rate <- 0.049


# Harvest rate -----------------------------------------------------------------
Hr <- 0 #.16 # latest estimate (from Eric Walther, May 2017; average)




params_steelhead <- list(pop_init = pop.init,
                         fecund_first = fecund.first,
                         fecund_respawn = fecund.respawn,
                         sex_ratio = 0.5,
                         percent_fall_migrants = percent.fall.migrants,
                         percent_spring_migrants = percent.spring.migrants,
                         prop_age1_smolts_w = prop.age1.smolts.w,
                         prop_age2_smolts_w = prop.age2.smolts.w,
                         prop_age1_smolts_s = prop.age1.smolts.s,
                         prop_age2_smolts_s = prop.age2.smolts.s,
                         bay_surv_w = bay.surv.w,
                         bay_surv_s = bay.surv.s,
                         so = so,
                         b1_1_w = b1_1w,
                         b1_2_w = b1_2w,
                         b2_1_w = b2_1w,
                         b2_2_w = b2_2w,
                         b3_1_w = b3_1w,
                         b1_1_s = b1_1s,
                         b1_2_s = b1_2s,
                         b2_1_s = b2_1s,
                         b2_2_s = b2_2s,
                         b3_1_s = b3_1s,
                         kelt_rate = kelt.rate,
                         hr = Hr)



