# Calculate metrics (for each site) 
# Last updated Nov 15 2021 AHF

# Load shapefiles (optional: for plotting)
stilly <- rgdal::readOGR("data", "NorWeST_ObsTemp_Stilly")
snoho <- rgdal::readOGR("data", "NorWeST_ObsTemp_Snohomish")

# Load daily summary data
td.stilly <- read.csv("data/NorWeST_ObservedStreamTemp_TempDailySummaries_Stillaguamish_AllDays.csv", header = T, stringsAsFactors = F)
td.snoho <- read.csv("data/NorWeST_ObservedStreamTemp_TempDailySummaries_Snohomish_AllDays.csv", header = T, stringsAsFactors = F)
td.stilly$Date <- as.Date(td.stilly$SampleDate, format = "%m/%d/%Y %H:%M:%S")
td.snoho$Date <- as.Date(td.snoho$SampleDate, format = "%m/%d/%Y %H:%M:%S")

#Get date windows for facets
fncFacetDates <- function(facet,yy){
  if(facet=="Jun1_21"){ start.date<- paste0(yy,"-06-01"); end.date<- paste0(yy,"-06-21")}
  if(facet=="7DADMax"){ start.date<- paste0(yy,"-07-01"); end.date<- paste0(yy,"-08-31")}
  if(facet=="Full"){ start.date<- paste0(yy,"-01-01"); end.date<- paste0(yy,"-12-31")}
  if(facet=="Winter"){ start.date<- paste0(yy,"-01-01"); end.date<- paste0(yy,"-03-31")}
  if(facet=="Spring"){ start.date<- paste0(yy,"-04-01"); end.date<- paste0(yy,"-06-30")}
  if(facet=="Summer"){ start.date<- paste0(yy,"-07-01"); end.date<- paste0(yy,"-09-30")}
  if(facet=="Fall"){ start.date<- paste0(yy,"-10-01"); end.date<- paste0(yy,"-12-31")}
  
  if(facet=="January"){ start.date<- paste0(yy,"-01-01"); end.date<- paste0(yy,"-01-31")}
  if(facet=="February"){ start.date<- paste0(yy,"-02-01"); end.date<- paste0(yy,"-02-28")}
  if(facet=="March"){ start.date<- paste0(yy,"-03-01"); end.date<- paste0(yy,"-03-31")}
  if(facet=="April"){ start.date<- paste0(yy,"-04-01"); end.date<- paste0(yy,"-04-30")}
  if(facet=="May"){ start.date<- paste0(yy,"-05-01"); end.date<- paste0(yy,"-05-31")}
  if(facet=="June"){ start.date<- paste0(yy,"-06-01"); end.date<- paste0(yy,"-06-30")}
  if(facet=="July"){ start.date<- paste0(yy,"-07-01"); end.date<- paste0(yy,"-07-31")}
  if(facet=="August"){ start.date<- paste0(yy,"-08-01"); end.date<- paste0(yy,"-08-31")}
  if(facet=="September"){ start.date<- paste0(yy,"-09-01"); end.date<- paste0(yy,"-09-30")}
  if(facet=="October"){ start.date<- paste0(yy,"-10-01"); end.date<- paste0(yy,"-10-31")}
  if(facet=="November"){ start.date<- paste0(yy,"-11-01"); end.date<- paste0(yy,"-11-30")}
  if(facet=="December"){ start.date<- paste0(yy,"-12-01"); end.date<- paste0(yy,"-12-31")}
  
  if(facet=="Coho.MigrSpawn"){ start.date<- paste0(yy-1,"-11-01"); end.date<- paste0(yy-1,"-12-31")} 
  if(facet=="Coho.EggIncub"){ start.date<- paste0(yy-1,"-11-15"); end.date<- paste0(yy,"-03-30")} 
  if(facet=="Coho.Rearing"){ start.date<- paste0(yy,"-04-01"); end.date<- paste0(yy+1,"-03-31")} 
  if(facet=="Coho.Smolt0"){ start.date<- paste0(yy,"-03-01"); end.date<- paste0(yy,"-11-01")} 
  if(facet=="Coho.Smolt1"){ start.date<- paste0(yy,"-03-01"); end.date<- paste0(yy,"-07-01")} 
  
  if(facet=="Chinook.MigrSpawn"){ start.date<- paste0(yy-1,"-06-01"); end.date<- paste0(yy-1,"-10-15")} 
  if(facet=="Chinook.EggIncub"){ start.date<- paste0(yy-1,"-09-01"); end.date<- paste0(yy,"-01-01")} 
  if(facet=="Chinook.Rearing"){ start.date<- paste0(yy-1,"-11-01"); end.date<- paste0(yy,"-04-01")} 
  if(facet=="Chinook.Smolt0"){ start.date<- paste0(yy-1,"-12-01"); end.date<- paste0(yy,"-03-01")} 
  if(facet=="Chinook.Smolt1"){ start.date<- paste0(yy,"-02-01"); end.date<- paste0(yy,"-08-15")} 
  
  if(facet=="Steelhead.MigrSpawn"){ start.date<- paste0(yy,"-01-01"); end.date<- paste0(yy,"-06-15")} 
  if(facet=="Steelhead.EggIncub"){ start.date<- paste0(yy,"-03-01"); end.date<- paste0(yy,"-06-01")} 
  if(facet=="Steelhead.Rearing"){ start.date<- paste0(yy,"-06-01"); end.date<- paste0(yy+1,"-08-15")} 
  if(facet=="Steelhead.Smolt0"){ start.date<- paste0(yy,"-02-01"); end.date<- paste0(yy,"-08-01")} 
  if(facet=="Steelhead.Smolt1"){ start.date<- paste0(yy,"-02-01"); end.date<- paste0(yy,"-08-01")} 
  
  if(facet=="Custom"){ start.date<- start.date; end.date<- end.date}
  
  start.date<- as.Date(start.date)
  end.date<- as.Date(end.date)
  return(c(start.date,end.date))
}

#Return data frame for facet window
fnc_DataSetup <- function(frame,facet, yy){
  
  #Get facet time window dates and no. of days in facet
  facet.start = data.start = fncFacetDates(facet,yy)[1]
  facet.end = data.end = fncFacetDates(facet,yy)[2]
  facet.days = as.integer(facet.end - facet.start + 1)
  
  #Get sites with data in this date window
  sites <- sort(unique(frame$OBSPRED_ID[frame$Date >= facet.start & frame$Date <= facet.end]))
  
  #Limit data.frame to facet time window
  frame2<- frame[frame$Date>= facet.start & frame$Date<=facet.end,]
  frame2 <- unique(frame2); frame2 <- frame2[!is.na(frame2$OBSPRED_ID),]
  rownames(frame2)<-NULL
  if(nrow(frame2)==0) return(NA) #proceed only if there are data remaining
  
  #Get time window for available data, if it is shorter than facet window
  if(min(frame2$Date)>facet.start) data.start = min(frame2$Date) #beginning of data
  if(max(frame2$Date)<facet.end) data.end = max(frame2$Date) #end of data
  
  #Sort
  frame2 <- frame2[order(frame2$OBSPRED_ID, frame2$Date),]
  
  #Ensure all days are accounted for (in case of gaps)
  file2keep <- NULL
  for(s in 1:length(sites)){
    frame3 <- as.data.frame(matrix(NA, as.numeric(data.end - data.start + 1), 2))
    colnames(frame3) <- c("Date", "OBSPRED_ID")
    frame3$Date <- seq(from = as.Date(data.start), to = as.Date(data.end), by = 1)
    frame3$OBSPRED_ID <- sites[s]
    frame3 <- merge(frame3, frame2[frame2$OBSPRED_ID == sites[s], c("Date", "DailyMax", "DailyMin", "DailyMean", "DailySD", "Nobs", "DailyRange")], by = "Date", all.x = T)
    file2keep <- rbind(file2keep, frame3)
  }

  
  return(list(
    "frame" = file2keep,
    "facet.start"=facet.start,
    "facet.end"=facet.end,
    "facet.days"=facet.days))
}

# Generic metric
fnc_Met <- function(frame = temp.df, site = site, start.date = facet.start, end.date = facet.end, metric = metric){
  j = which(frame$OBSPRED_ID==site)
  start = which(frame$Date >= start.date & frame$OBSPRED_ID == site)[1]
  end = which(frame$Date <= end.date & frame$OBSPRED_ID == site)[length(which(frame$Date <= end.date & frame$OBSPRED_ID == site))]
  frame = frame[c(start:end),c("OBSPRED_ID", "Date", "DailyMax", "DailyMin", "DailyMean", "DailySD", "Nobs", "DailyRange")]
  
  return(mean(frame[,metric], na.rm=TRUE))	
}
#fnc_Met(frame, site, start.date, end.date, metric)

# 7DADMax
fnc_7DADMax <- function(frame = temp.df, site = site, start.date = facet.start, end.date = facet.end, metric = "DailyMax"){
  j = which(frame$OBSPRED_ID==site)
  start = which(frame$Date >= start.date & frame$OBSPRED_ID == site)[1]
  end = which(frame$Date <= end.date & frame$OBSPRED_ID == site)[length(which(frame$Date <= end.date & frame$OBSPRED_ID == site))]
  frame = frame[c(start:end),c("OBSPRED_ID", "Date", "DailyMax")]
  datelist = unique(frame$Date)
  
  maxlist = rep(0,length(datelist))
  mwmtlist = rep(0,(length(datelist)-6))
  for (i in 1:length(datelist)){
    maxlist[i] = max(frame[which(frame$Date == datelist[i]), metric])	
  }
  for (i in 1:(length(datelist)-6)){
    mwmtlist[i] = mean(maxlist[i:(i+6)])
  }
  
  return(max(mwmtlist,na.rm=TRUE))	

}

# Return metrics
calculate.metrics <- function(site, frame, start.date, end.date, facet){
  MT = fnc_Met(frame,site, start.date, end.date, metric = "DailyMax")
  AT = round(fnc_Met(frame, site, start.date, end.date, metric = "DailyMean"), 2)
  mT = fnc_Met(frame, site, start.date, end.date, metric = "DailyMin")
  Rg = fnc_Met(frame, site, start.date, end.date, metric = "DailyRange")
  Sv = fnc_7DADMax(frame,site, start.date, end.date, metric = "DailyMax")
  result <- cbind.data.frame("facet" = facet, start.date, end.date, "OBSPRED_ID" = site, MT, AT, mT, Rg, Sv)
  
  return(result)
}

# adapted for Snoqualmie data, which are set up differently:
fnc_Met2 <- function(frame = temp.df, site = site, start.date = facet.start, end.date = facet.end, metric = "mean"){
  j = which(colnames(frame)==site)
  start = which(frame$Date >= start.date)[1]
  end = which(frame$Date <= end.date)[length(which(frame$Date <= end.date))]
  if(length(end) > 0){
    frame = frame[c(start:end),c("Date", site)]
    met.fun <- get(metric)
    return(met.fun(frame[,site], na.rm=TRUE))	
    
  } else {return(NA)}
}
fnc_7DADMax2 <- function(frame = temp.df, site = site, start.date = facet.start, end.date = facet.end){
  j = which(colnames(frame)==site)
  start = which(frame$Date >= start.date)[1]
  end = which(frame$Date <= end.date)[length(which(frame$Date <= end.date))]
  if(length(end) > 0){
    frame = frame[c(start:end),c("Date", site)]
    datelist = unique(frame$Date)
    
    maxlist = rep(0,length(datelist))
    mwmtlist = rep(0,(length(datelist)-6))
    for (i in 1:length(datelist)){
      maxlist[i] = max(frame[which(frame$Date == datelist[i]), site])	
    }
    for (i in 1:(length(datelist)-6)){
      mwmtlist[i] = mean(maxlist[i:(i+6)])
    }
    
    return(max(mwmtlist,na.rm=TRUE))	
  } else {return(NA)}
  
}
calculate.metrics2 <- function(site, frame, start.date, end.date, facet){
  MT = fnc_Met2(frame,site, start.date, end.date, metric = "max")
  AT = round(fnc_Met2(frame, site, start.date, end.date, metric = "mean"), 2)
  mT = fnc_Met2(frame, site, start.date, end.date, metric = "min")
  Rg = fnc_Met2(frame, site, start.date, end.date, metric = "range")[2] - fnc_Met2(frame, site, start.date, end.date, metric = "range")[1]
  Sv = fnc_7DADMax2(frame,site, start.date, end.date)
  result <- cbind.data.frame("facet" = facet, start.date, end.date, "SiteID" = site, MT, AT, mT, Rg, Sv)
  
  return(result)
}



# Choose facets
facets <- c("Jun1_21", "7DADMax")
#facets <- c("Full", "Winter", "Spring", "Summer", "Fall", "January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December")
# life.stages<- c("MigrSpawn","EggIncub","Rearing","Smolt0","Smolt1")
# species<- c("Coho","Chinook","Steelhead")
# for(i in 1:length(species)){
#   for(j in 1:length(life.stages)){
#     facets<- c(facets,paste0(species[i],".",life.stages[j]))
#   }
# }


# Calculate metrics
thebasin <- "stilly"
if(thebasin == "stilly") the.data <- td.stilly else the.data <- td.snoho
(years.with.data <- sort(unique(1900+as.POSIXlt(the.data$Date)$year)))

annual.metrics <- NULL
for(yy in years.with.data){
  all.metrics <- NULL
  for(facet in facets){
    
    data.info = fnc_DataSetup(frame = the.data, facet, yy) 
    if(length(names(data.info))>0){
      temp.df <- data.info[[1]]
      facet.start <- data.info[[2]]
      facet.end <- data.info[[3]]
      facet.days <- data.info[[4]]
      
      sites <- sort(unique(temp.df$OBSPRED_ID))
      
      facet.metrics <- NULL
      for(site in sites){
        metrics <- calculate.metrics(site, frame = temp.df, start.date = facet.start, end.date = facet.end, facet = facet)
        if(!is.null(metrics)){ 
          facet.metrics <- rbind(facet.metrics,metrics)
        }
      }
      all.metrics <- rbind(all.metrics,facet.metrics)
    }# end check for data
  }# end facet
  annual.metrics <- rbind(annual.metrics, all.metrics)
}
annual.metrics$Sv[is.infinite(annual.metrics$Sv)] <- NA

write.csv(annual.metrics, paste0(thebasin, "_temperature_metrics.csv"), row.names = F)


# SNOQUALMIE
thebasin <- "snoq"
td <- read.csv("/Users/aimee_fullerton/OneDrive/Work/Research/StreamTemperature/HoboNet/Data/snoqualmie.wt.allyears_2021.csv", header = T, stringsAsFactors = F)
td$Date<- as.Date(td$Date)

annual.metrics <- NULL
for(yy in unique(lubridate::year(td$Date))){
    all.metrics <- NULL
    for(facet in facets){
      
        sites <- sort(unique(colnames(td)[3:length(colnames(td))]))
        facet.start <- as.Date(fncFacetDates(facet, yy)[1])
        facet.end <- as.Date(fncFacetDates(facet, yy)[2])
        
        facet.metrics <- NULL
        for(site in sites){
          metrics <- calculate.metrics2(site, frame = td, start.date = facet.start, end.date = facet.end, facet = facet)
          if(!is.null(metrics)){ 
            facet.metrics <- rbind(facet.metrics,metrics)
          }
        }
        all.metrics <- rbind(all.metrics,facet.metrics)
    }# end facet
annual.metrics <- rbind(annual.metrics, all.metrics)
}# end annual
idx <- which(is.infinite(annual.metrics$mT))
annual.metrics <- annual.metrics[-idx,]
idx <- which(is.na(annual.metrics$mT))
annual.metrics <- annual.metrics[-idx,]
write.csv(annual.metrics, paste0(thebasin, "_temperature_metrics.csv"), row.names = F)
  