# check for inter-basin stability over time
devtools::load_all()
library(ggplot2)

long_chinook <- hab_run_diagnostic("fall_chinook") %>%
  expand_grid(year=1:1000) %>%
  lcm_assign() %>%
  lcm_run()

long_coho <- hab_run_diagnostic("coho") %>%
  expand_grid(year=1:1000) %>%
  lcm_assign() %>%
  lcm_run()

long_steelhead <- lcm_assign_steelhead(
  expand_grid(hab_run_diagnostic("winter_steelhead"), year=1:1000),
  expand_grid(hab_run_diagnostic("summer_steelhead"), year=1:1000)) %>%
  lcm_run()

long_everyone <- bind_rows(
  long_chinook,
  long_coho,
  long_steelhead) %>%
  group_by(pop, subbasin) %>%
  mutate(
    startfish = n[year == 1],
    nchange = (n-startfish),
    pchange = nchange/startfish,
    year = as.numeric(year))

millenial_results <- long_everyone %>%
  filter(startfish > 1, year == 1000)

big_results <- long_everyone %>%
  filter(startfish > 1, pchange >0.1)

long_everyone %>%
  group_by(pop) %>%
  filter(startfish > 1) %>%
  summarize(
    max_pchange = max(abs(pchange), na.rm = T),
    max_nchange = max(abs(nchange), na.rm = T))

some_results <- long_everyone %>%
  filter(
    pop == "steelhead",
    subbasin %in% c(
      "mainstem_South_Fork_Stillaguamish_05",
      "mainstem_South_Fork_Stillaguamish_02"))

some_results %>%
  ggplot(aes(year, nchange, color = subbasin, group = subbasin)) +
  geom_line()+
  cowplot::theme_minimal_grid()
