library(tidyverse)
library(cowplot)

# setup base steelhead habitat run
coho_hab <- hab_run("coho", "Current", "curr") %>%
  lcm_assign()

# function to run steelhead with modified movement multipliers

fix_migrants <- function(migr_fix){
  coho_hab %>%
    mutate(percent_fry_migrants = migr_fix)%>%
    lcm_run() %>%
    filter(year == 100) %>%
    summarize(n = sum(n)) %>%
    mutate(
      trans = "fixed",
      value = migr_fix)
}


# run models with variety of parameters,
# get df out for each type of modification
coho_migration_fixed <- map_df(seq(0,0.1,0.005), fix_migrants)

# base function plot
plot_coho <- function(df, x){
  ggplot(df, aes(value, n))+
    #geom_point(size = 1)+
    geom_line()+
    theme_cowplot()+
    theme(axis.title.y = element_text(color = "gray"))+
    labs(y = "Basinwide Coho Spawners", x = x)+
    scale_x_continuous(labels = scales::percent_format())
}

# plot each
p1 <- plot_coho(coho_migration_fixed, "Percent Fry Migration")
p1

plot_grid(
  plotlist = list(p1)) %>%
  save_plot(
    sprintf("ignore/coho_migration_diagnostics_%s.png", Sys.Date()),
    .,
    base_height = 5)
