library(tidyverse)
load_all()

hab_base <- hab_run("fall_chinook", "Current", "curr") %>%
  lcm_assign()

hab_base_coho <- hab_run("coho", "Current", "curr") %>%
  lcm_assign()

modify_bay <- function(new_surv){
  hab_base %>%
    mutate(bay_parr_surv = new_surv, bay_fry_surv = new_surv/60) %>%
    lcm_run("all") %>%
    filter(
      year == 100,
      lifestage %in% c("spawners", "total_run", "sub_yr")
    ) %>%
    group_by(lifestage) %>%
    summarize(n = sum(n)) %>%
    pivot_wider(names_from = lifestage, values_from = n) %>%
    mutate(SAR = total_run/sub_yr, bay = new_surv, pop = "Chinook")
}

modify_bay_coho <- function(new_surv){
  hab_base_coho %>%
    mutate(bay = new_surv) %>%
    lcm_run("all") %>%
    filter(
      year == 100,
      lifestage %in% c("spawners", "total_run", "smolts")
    ) %>%
    group_by(lifestage) %>%
    summarize(n = sum(n)) %>%
    pivot_wider(names_from = lifestage, values_from = n) %>%
    mutate(SAR = total_run/smolts, bay = new_surv, pop = "Coho")
}

modify_bay(hab_base$bay_parr_surv[1])
modify_bay_coho(hab_base_coho$bay[1])

new_vals_chinook <- map_dfr(seq(0.01, 0.06, 0.001), ~ modify_bay(.x))
new_vals_coho <- map_dfr(seq(0.01, 0.18, 0.01), ~ modify_bay_coho(.x))

escapement <- data.frame(
  pop = c("Chinook", "Coho", "Steelhead"),
  n = c(982, 19495, NA),
  observed = "Median Esc.",
  SAR = c(0.011,0.041,NA)) %>%
  filter(pop != "Steelhead")

ggplot(bind_rows(new_vals_chinook, new_vals_coho)) +
  geom_hline(aes(yintercept = n, color = observed), data = escapement)+
  geom_vline(
    aes(xintercept = SAR),
    data = escapement,
    color = "gray50", linetype = 2)+
  geom_line(aes(SAR, spawners)) +
  facet_wrap("pop", scales = "free")+
  scale_x_continuous(labels = scales::label_percent())+
  #geom_point(aes(SAR, spawners)) +
  cowplot::theme_minimal_grid()+
  labs(y = "Spawners", title = "Stillaguamish single-SAR")+
  theme(legend.title = element_blank(), legend.position = "bottom")

ggsave(sprintf("ignore/results/spawners_v_SAR_STL_%s.png", Sys.Date()))
