library(tidyverse)
load_all()

hab_base_chinook <- hab_run("fall_chinook", "Current", "curr") %>%
  lcm_assign()

hab_base_coho <- hab_run("coho", "Current", "curr") %>%
  lcm_assign()

hab_base_steelhead <- lcm_assign_steelhead(
  hab_run("winter_steelhead", "Current", "curr"),
  hab_run("summer_steelhead", "Current", "curr")
)

adj_e2f <- function(adj, hab_base){
  pop = unique(hab_base$pop)
  mutate(hab_base, egg_fry_surv = pmin(egg_fry_surv*adj, 1)) %>%
    lcm_run() %>%
    filter(year == 100) %>%
    summarize(n = sum(n)) %>%
    mutate(adj = adj, pop = pop)
}

adj_e2f_steelhead <- function(adj){
  pop = "Steelhead"
  mutate(
    hab_base_steelhead,
    egg_fry_surv_w = pmin(egg_fry_surv_w*adj, 1),
    egg_fry_surv_s = pmin(egg_fry_surv_s*adj, 1)) %>%
    lcm_run() %>%
    filter(year == 100) %>%
    summarize(n = sum(n)) %>%
    mutate(adj = adj, pop = pop)
}

e2f_chinook <- map_dfr(
  seq(0.1, 1.5, 0.05),
  ~adj_e2f(.x, hab_base_chinook))
e2f_coho <- map_dfr(
  seq(0.1, 1.5, 0.05),
  ~adj_e2f(.x, hab_base_coho))
e2f_steelhead <- map_dfr(
  seq(0.1, 1.5, 0.05),
  adj_e2f_steelhead)

escapement <- data.frame(
  pop = c("Chinook", "Coho", "Steelhead"),
  n = c(982, 19495, NA),
  observed = "Median Esc.",
  SAR = c(0.11,0.041,NA))

bind_rows(e2f_chinook, e2f_coho, e2f_steelhead) %>%
  mutate(pop = case_when(
    pop == "fall_chinook" ~ "Chinook",
    pop == "coho" ~ "Coho",
    pop == "Steelhead" ~ "Steelhead"
  )) %>%
  ggplot()+
  geom_hline(aes(yintercept = n), color = "pink", data = escapement)+
  geom_vline(
    xintercept = 1,
    color = "gray50", linetype = 2)+
  geom_line(aes(adj, n))+
  facet_wrap("pop", scales = "free")+
  scale_x_continuous(labels = scales::label_percent())+
  cowplot::theme_minimal_grid()+
  labs(x = "Incub. Productivity Adjustment", y = "Spawners",
       title = "Stillaguamish")

ggsave(sprintf("ignore/results/spawners_v_e2f_STL_%s.png", Sys.Date()),
       width = 8, height = 4)
