library(tidyverse)
load_all()

harp::temperature_df %>%
  left_join(filter(harp::flowline_clean, pop == "fall_chinook")) %>%
  filter(scenario == "Current", era == "curr", rear) %>%
  mutate(chinook_stress = temp_Jn121 > 18) %>%
  group_by(chinook_stress) %>%
  summarize(reaches = n()) %>%
  ungroup() %>%
  mutate(n = sum(reaches), percent = reaches/n)
  # only 2.5% of reaches are chinook temp stressed


vary_temp <- function(pop, temp_change){ # vary summer and winter together
  temp_mod <- harp::temperature_df %>%
    mutate(
      noaaid,
      # only adjust small streams, cap expansion at 30 m
      temp_Jn121 = temp_Jn121+temp_change,
      temp_7DADM = temp_7DADM+temp_change
    )

  hab_run(pop, "Current", "curr", df_temperature = temp_mod)
}

vary_temp("fall_chinook", 3) %>%
  lcm_assign() %>% lcm_run() %>% filter(year == 100) %>% summarize(n = sum(n))


sum_spawners_temp <- function(pop, temp_change){
  suppressMessages(vary_temp(pop, temp_change)) %>%
    lcm_assign() %>% lcm_run() %>%
    filter(year == 100) %>%
    summarize(n = sum(n)) %>%
    mutate(pop = pop, temp_change = temp_change)
}

sum_spawners_temp_stlhd <- function(temp_change){
  suppressMessages(
    lcm_assign_steelhead(
      vary_temp("winter_steelhead", temp_change),
      vary_temp("summer_steelhead", temp_change))) %>%
    lcm_run() %>%
    filter(year == 100) %>%
    summarize(n = sum(n)) %>%
    mutate(pop = "steelhead", temp_change = temp_change)
}

temp_results_cc <- crossing(seq(-5, 5, 0.2), c("coho", "fall_chinook")) %>%
  pmap_dfr(~sum_spawners_temp(..2, ..1))

temp_results_stlhd <- map_dfr(
  seq(-5, 5, 0.2),
  ~sum_spawners_temp_stlhd(.x))

escapement <- data.frame(
  pop = c("Chinook", "Coho", "Steelhead"),
  n = c(982, 19495, NA),
  observed = "Median Esc.",
  SAR = c(0.11,0.041,NA))

bind_rows(temp_results_cc, temp_results_stlhd) %>%
  mutate(pop = case_when(
    pop == "coho" ~ "Coho",
    pop == "fall_chinook" ~ "Chinook",
    pop == "steelhead" ~ "Steelhead"
  )) %>%
  ggplot()+
  geom_hline(aes(yintercept = n, color = observed), data = escapement)+
  geom_vline(
    xintercept = 0,
    data = escapement,
    color = "gray50", linetype = 2)+
  geom_line(aes(temp_change, n))+
  facet_wrap("pop", scales = "free")+
  cowplot::theme_half_open() +
  labs(y = 'Spawners',
       x = 'Temp Increase (Degrees C)',
       color = NULL, title = "Stillaguamish")+
  theme(panel.grid.major = element_line('grey90'),
        strip.background = element_rect(fill = NA),
        legend.position = "bottom")

ggsave(
  sprintf("ignore/results/spawners_v_temp_STL_%s.png", Sys.Date()),
  width = 8,
  height = 4.5)
