library(tidyverse)
library(cowplot)

# setup base steelhead habitat run
steelhead_hab <- lcm_assign_steelhead(
  hab_run('winter_steelhead', 'Current', 'curr'),
  hab_run('summer_steelhead', 'Current', 'curr'))

# function to run steelhead with modified movement multipliers
mult_migrants <- function(migr_mult){
  steelhead_hab %>%
    mutate(
      percent_fall_migrants = percent_fall_migrants*migr_mult,
      percent_spring_migrants = percent_spring_migrants*migr_mult) %>%
    lcm_run() %>%
    filter(year == 100) %>%
    summarize(n = sum(n)) %>%
    mutate(
      trans = "mult",
      value = migr_mult)
}

fix_migrants <- function(migr_fix){
  steelhead_hab %>%
    mutate(
      percent_fall_migrants = migr_fix,
      percent_spring_migrants = migr_fix)%>%
    lcm_run() %>%
    filter(year == 100) %>%
    summarize(n = sum(n)) %>%
    mutate(
      trans = "fixed",
      value = migr_fix)
}

fix_migrants_fall <- function(migr_fix){
  steelhead_hab %>%
    mutate(
      percent_fall_migrants = migr_fix)%>%
    lcm_run() %>%
    filter(year == 100) %>%
    summarize(n = sum(n)) %>%
    mutate(
      trans = "fixed_fall",
      value = migr_fix)
}

fix_migrants_spring <- function(migr_fix){
  steelhead_hab %>%
    mutate(
      percent_spring_migrants = migr_fix)%>%
    lcm_run() %>%
    filter(year == 100) %>%
    summarize(n = sum(n)) %>%
    mutate(
      trans = "fixed_spring",
      value = migr_fix)
}

# run models with variety of parameters,
# get df out for each type of modification
steelhead_migration_mult <- map_df(seq(0,1,0.1), mult_migrants)
steelhead_migration_fixed <- map_df(seq(0,0.5,0.01), fix_migrants)

steelhead_migration_fixed_spring <- map_df(seq(0,0.5,0.01), fix_migrants_spring)
steelhead_migration_fixed_fall <- map_df(seq(0,0.1,0.01), fix_migrants_fall)

# base function plot
plot_steels <- function(df, x){
  ggplot(df, aes(value, n))+
    #geom_point(size = 1)+
    geom_line()+
    theme_cowplot()+
    theme(axis.title.y = element_text(color = "gray"))+
    labs(y = "Basinwide Spawners", x = x)+
    scale_x_continuous(labels = scales::percent_format())
}

# plot each
p1 <- plot_steels(steelhead_migration_mult, "Percent of Default Migration")
p2 <- plot_steels(steelhead_migration_fixed, "Fixed Percent Migration")
p3 <- plot_steels(steelhead_migration_fixed_spring,
                  "Fixed Percent Spring Migration,\nDefault Fall Migration")
p4 <- plot_steels(steelhead_migration_fixed_fall,
                  "Fixed Percent Fall Migration,\nDefault Spring Migration")

# combine plots
plot_grid(
  plotlist = list(p1, p2, p3, p4)) %>%
  save_plot(
    sprintf("ignore/steelhead_migration_diagnostics_%s.png", Sys.Date()),
    .,
    base_height = 5)
