% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hab_run.R
\name{hab_run}
\alias{hab_run}
\title{Run the Stillaguamish habitat model}
\usage{
hab_run(
  run_pop,
  run_scenario,
  run_era,
  beaver_model = "BIP",
  df_temperature = harp::temperature_df,
  df_width = harp::width_df,
  df_fl = harp::flowline_clean[harp::flowline_clean$pop == run_pop, ],
  pass_mort = TRUE
)
}
\arguments{
\item{run_pop}{which pop to run}

\item{run_scenario}{which scenario to run.}

\item{run_era}{which era to run. The choices are hist, curr, mid, late.}

\item{df_temperature}{default is \code{harp::temperature_df}. Vary temps here}

\item{df_width}{default is \code{harp::width_df}. Vary widths here}

\item{df_fl}{all flowline reaches for the pop of interest}

\item{pass_mort}{should partial passage affect prespawn mortality?}
}
\description{
Run the habitat model based on specified input.
}
\section{Detailed Options}{

\itemize{
\item \code{run_pop} can take any of the following values:
\itemize{
\item \code{"coho"}, \code{"fall_chinook"}, \code{"winter_steelhead"}, \code{"summer_steelhead"}
}
\item \code{run_scenario} can take any of the following values:
\itemize{
\item \code{"Current"}, \code{"Barriers"}, \code{"Fine_sediment"}, \code{"Wood"}, \code{"Shade"}, \code{"LR"}, \code{"Beaver"}, \code{"Floodplain"}, \code{"FP_wood_comb"}, \code{"Delta"}, \code{"Historical"}, \code{"Top4_25\%"}, \code{"Top4_50\%"}, \code{"Top4_75\%"}, \code{"Top5_25\%"}, \code{"Top5_50\%"}, \code{"Top5_75\%"}, \code{"All_25\%"}, \code{"All_50\%"}, \code{"All_75\%"}, \code{"All_100\%"}
}
\item \code{run_era} can take any of the following values:
\itemize{
\item \code{"hist"}, \code{"curr"}
}
\item \code{beaver_model} can take either of the following values:
\itemize{
\item \code{"BP"}, \code{"SP"}
}
}
}

\examples{
# hab_run() requires a run_pop, run_scenario, and run_era.
hab_run("winter_steelhead", "Shade", "curr")

# other parameters may also be specified
hab_run("winter_steelhead", "Shade", "curr", pass_mort = FALSE)

# the default temperature, width, and flowline data frames can be replaced
hab_run("winter_steelhead", "Shade", "curr", df_width = custom_width_df)

}
