% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hab_run.R
\name{hab_run_diagnostic}
\alias{hab_run_diagnostic}
\title{Run the habitat model (diagnostic)}
\usage{
hab_run_diagnostic(
  run_pop,
  run_scenario = "Current",
  run_era = "curr",
  beaver_model = "BIP",
  df_temperature = harp::temperature_df,
  df_width = harp::width_df,
  df_fl = harp::flowline_clean[harp::flowline_clean$pop == run_pop, ],
  pass_mort = TRUE,
  return_df = "results"
)
}
\arguments{
\item{run_pop}{which pop to run}

\item{run_scenario}{which scenario to run.}

\item{run_era}{which era to run. The choices are hist, curr, mid, late.}

\item{df_temperature}{default is \code{harp::temperature_df}. Vary temps here}

\item{df_width}{default is \code{harp::width_df}. Vary widths here}

\item{df_fl}{all flowline reaches for the pop of interest}

\item{pass_mort}{should partial passage affect prespawn mortality?}

\item{return_df}{which data frame to return}
}
\description{
Create habitat scenarios, output data frame of choice.
See documentation for \code{\link{hab_run()}} to see general options
}
\section{Output Options for return_df}{

\itemize{
\item \code{"results"} Full model output, the default
\item \code{"df_ss_clean"} Small streams
\item \code{"df_ss"} Small stream lengths, accounting for beavers
\item \code{"df_ss_area"} Small stream rearing areas
\item \code{"df_sch"} Side channel habitats
\item \code{"df_fp_clean"} Combined floodplain habitats
\item \code{"df_fp"} Floodplain rearing areas
\item \code{"df_lr"} Large rivers
\item \code{"df_bw"} Backwaters
\item \code{"df_lr_clean"} Length-adjusted large rivers
\item \code{"df_w"} Wood multipliers
\item \code{"df_lr_area"} Large river rearing area
\item \code{"df_cap"} Rearing capacity, by reach and habitat
\item \code{"df_prod"} Rearing productivities
\item \code{"df_mvmt"} Movement values, based on scenario
\item \code{"df_spss"} Small stream spawning habitats
\item \code{"df_spfp"} Floodplain spawning habitats
\item \code{"df_splr_clean"} Large river spawning habitats
\item \code{"df_cap_spawn"} Habitat and reach -level spawning capacities
\item \code{"df_cap_egg"} Reach-level spawning capacities
\item \code{"df_prod_e2f"} Subbasin-level incubation productivities
\item \code{"df_prod_prespawn"} Subbasin-level prespawn survivial
}
}

\examples{
# By default, hab_run_diagnostic() runs in the Current scenario and curr era
hab_run_diagnostic("coho")

# You can specify a different diagnostic scenario as well
hab_run_diagnostic("coho", "LR")
hab_run_diagnostic("coho", run_scenario = "LR")

# Set return_df to return any data frame used in the habitat model.
hab_run_diagnostic("fall_chinook", return_df = "df_cap_spawn")

# If a return data frame is not specified, the function will return the
"results" data frame, like hab_run().
# These two functions will produce the same results:

hab_run_diagnostic(
  "fall_chinook", "Historical", "hist", pass_mort = FALSE)

hab_run(
  "fall_chinook", "Historical", "hist", pass_mort = FALSE)

}
\seealso{
\code{hab_run()}
}
